Class: TurnkeyClient::Activity
- Inherits:
-
Object
- Object
- TurnkeyClient::Activity
- Defined in:
- lib/turnkey_client/models/activity.rb
Instance Attribute Summary collapse
-
#app_proofs ⇒ Object
A list of App Proofs generated by enclaves during activity execution, providing verifiable attestations of performed operations.
-
#can_approve ⇒ Object
Returns the value of attribute can_approve.
-
#can_reject ⇒ Object
Returns the value of attribute can_reject.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#failure ⇒ Object
Returns the value of attribute failure.
-
#fingerprint ⇒ Object
An artifact verifying a User’s action.
-
#id ⇒ Object
Unique identifier for a given Activity object.
-
#intent ⇒ Object
Returns the value of attribute intent.
-
#organization_id ⇒ Object
Unique identifier for a given Organization.
-
#result ⇒ Object
Returns the value of attribute result.
-
#status ⇒ Object
Returns the value of attribute status.
-
#type ⇒ Object
Returns the value of attribute type.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#votes ⇒ Object
A list of objects representing a particular User’s approval or rejection of a Consensus request, including all relevant metadata.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Activity
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Activity
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/turnkey_client/models/activity.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TurnkeyClient::Activity` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TurnkeyClient::Activity`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'organization_id') self.organization_id = attributes[:'organization_id'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'intent') self.intent = attributes[:'intent'] end if attributes.key?(:'result') self.result = attributes[:'result'] end if attributes.key?(:'votes') if (value = attributes[:'votes']).is_a?(Array) self.votes = value end end if attributes.key?(:'app_proofs') if (value = attributes[:'app_proofs']).is_a?(Array) self.app_proofs = value end end if attributes.key?(:'fingerprint') self.fingerprint = attributes[:'fingerprint'] end if attributes.key?(:'can_approve') self.can_approve = attributes[:'can_approve'] end if attributes.key?(:'can_reject') self.can_reject = attributes[:'can_reject'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'failure') self.failure = attributes[:'failure'] end end |
Instance Attribute Details
#app_proofs ⇒ Object
A list of App Proofs generated by enclaves during activity execution, providing verifiable attestations of performed operations.
33 34 35 |
# File 'lib/turnkey_client/models/activity.rb', line 33 def app_proofs @app_proofs end |
#can_approve ⇒ Object
Returns the value of attribute can_approve.
38 39 40 |
# File 'lib/turnkey_client/models/activity.rb', line 38 def can_approve @can_approve end |
#can_reject ⇒ Object
Returns the value of attribute can_reject.
40 41 42 |
# File 'lib/turnkey_client/models/activity.rb', line 40 def can_reject @can_reject end |
#created_at ⇒ Object
Returns the value of attribute created_at.
42 43 44 |
# File 'lib/turnkey_client/models/activity.rb', line 42 def created_at @created_at end |
#failure ⇒ Object
Returns the value of attribute failure.
46 47 48 |
# File 'lib/turnkey_client/models/activity.rb', line 46 def failure @failure end |
#fingerprint ⇒ Object
An artifact verifying a User’s action.
36 37 38 |
# File 'lib/turnkey_client/models/activity.rb', line 36 def fingerprint @fingerprint end |
#id ⇒ Object
Unique identifier for a given Activity object.
16 17 18 |
# File 'lib/turnkey_client/models/activity.rb', line 16 def id @id end |
#intent ⇒ Object
Returns the value of attribute intent.
25 26 27 |
# File 'lib/turnkey_client/models/activity.rb', line 25 def intent @intent end |
#organization_id ⇒ Object
Unique identifier for a given Organization.
19 20 21 |
# File 'lib/turnkey_client/models/activity.rb', line 19 def organization_id @organization_id end |
#result ⇒ Object
Returns the value of attribute result.
27 28 29 |
# File 'lib/turnkey_client/models/activity.rb', line 27 def result @result end |
#status ⇒ Object
Returns the value of attribute status.
21 22 23 |
# File 'lib/turnkey_client/models/activity.rb', line 21 def status @status end |
#type ⇒ Object
Returns the value of attribute type.
23 24 25 |
# File 'lib/turnkey_client/models/activity.rb', line 23 def type @type end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
44 45 46 |
# File 'lib/turnkey_client/models/activity.rb', line 44 def updated_at @updated_at end |
#votes ⇒ Object
A list of objects representing a particular User’s approval or rejection of a Consensus request, including all relevant metadata.
30 31 32 |
# File 'lib/turnkey_client/models/activity.rb', line 30 def votes @votes end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/turnkey_client/models/activity.rb', line 49 def self.attribute_map { :'id' => :'id', :'organization_id' => :'organizationId', :'status' => :'status', :'type' => :'type', :'intent' => :'intent', :'result' => :'result', :'votes' => :'votes', :'app_proofs' => :'appProofs', :'fingerprint' => :'fingerprint', :'can_approve' => :'canApprove', :'can_reject' => :'canReject', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt', :'failure' => :'failure' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
279 280 281 |
# File 'lib/turnkey_client/models/activity.rb', line 279 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 |
# File 'lib/turnkey_client/models/activity.rb', line 89 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/turnkey_client/models/activity.rb', line 69 def self.openapi_types { :'id' => :'Object', :'organization_id' => :'Object', :'status' => :'Object', :'type' => :'Object', :'intent' => :'Object', :'result' => :'Object', :'votes' => :'Object', :'app_proofs' => :'Object', :'fingerprint' => :'Object', :'can_approve' => :'Object', :'can_reject' => :'Object', :'created_at' => :'Object', :'updated_at' => :'Object', :'failure' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/turnkey_client/models/activity.rb', line 245 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && organization_id == o.organization_id && status == o.status && type == o.type && intent == o.intent && result == o.result && votes == o.votes && app_proofs == o.app_proofs && fingerprint == o.fingerprint && can_approve == o.can_approve && can_reject == o.can_reject && created_at == o.created_at && updated_at == o.updated_at && failure == o.failure end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/turnkey_client/models/activity.rb', line 309 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TurnkeyClient.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'lib/turnkey_client/models/activity.rb', line 378 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/turnkey_client/models/activity.rb', line 286 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) end end self end |
#eql?(o) ⇒ Boolean
266 267 268 |
# File 'lib/turnkey_client/models/activity.rb', line 266 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
272 273 274 |
# File 'lib/turnkey_client/models/activity.rb', line 272 def hash [id, organization_id, status, type, intent, result, votes, app_proofs, fingerprint, can_approve, can_reject, created_at, updated_at, failure].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/turnkey_client/models/activity.rb', line 172 def list_invalid_properties invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @organization_id.nil? invalid_properties.push('invalid value for "organization_id", organization_id cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @intent.nil? invalid_properties.push('invalid value for "intent", intent cannot be nil.') end if @result.nil? invalid_properties.push('invalid value for "result", result cannot be nil.') end if @votes.nil? invalid_properties.push('invalid value for "votes", votes cannot be nil.') end if @fingerprint.nil? invalid_properties.push('invalid value for "fingerprint", fingerprint cannot be nil.') end if @can_approve.nil? invalid_properties.push('invalid value for "can_approve", can_approve cannot be nil.') end if @can_reject.nil? invalid_properties.push('invalid value for "can_reject", can_reject cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
354 355 356 |
# File 'lib/turnkey_client/models/activity.rb', line 354 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/turnkey_client/models/activity.rb', line 360 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
348 349 350 |
# File 'lib/turnkey_client/models/activity.rb', line 348 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/turnkey_client/models/activity.rb', line 227 def valid? return false if @id.nil? return false if @organization_id.nil? return false if @status.nil? return false if @type.nil? return false if @intent.nil? return false if @result.nil? return false if @votes.nil? return false if @fingerprint.nil? return false if @can_approve.nil? return false if @can_reject.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |