Class: TurnkeyClient::AppProofApi
- Inherits:
-
Object
- Object
- TurnkeyClient::AppProofApi
- Defined in:
- lib/turnkey_client/api/app_proof_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_app_proofs(body, opts = {}) ⇒ GetAppProofsResponse
List App Proofs for an activity List the App Proofs for the given activity.
-
#get_app_proofs_with_http_info(body, opts = {}) ⇒ Array<(GetAppProofsResponse, Integer, Hash)>
List App Proofs for an activity List the App Proofs for the given activity.
-
#initialize(api_client = ApiClient.default) ⇒ AppProofApi
constructor
A new instance of AppProofApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AppProofApi
Returns a new instance of AppProofApi.
15 16 17 |
# File 'lib/turnkey_client/api/app_proof_api.rb', line 15 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
13 14 15 |
# File 'lib/turnkey_client/api/app_proof_api.rb', line 13 def api_client @api_client end |
Instance Method Details
#get_app_proofs(body, opts = {}) ⇒ GetAppProofsResponse
List App Proofs for an activity List the App Proofs for the given activity.
23 24 25 26 |
# File 'lib/turnkey_client/api/app_proof_api.rb', line 23 def get_app_proofs(body, opts = {}) data, _status_code, _headers = get_app_proofs_with_http_info(body, opts) data end |
#get_app_proofs_with_http_info(body, opts = {}) ⇒ Array<(GetAppProofsResponse, Integer, Hash)>
List App Proofs for an activity List the App Proofs for the given activity.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/turnkey_client/api/app_proof_api.rb', line 33 def get_app_proofs_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AppProofApi.get_app_proofs ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling AppProofApi.get_app_proofs" end # resource path local_var_path = '/public/v1/query/list_app_proofs' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'GetAppProofsResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: AppProofApi#get_app_proofs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |