Class: TurnkeyClient::AuthenticatorAttestationResponse
- Inherits:
-
Object
- Object
- TurnkeyClient::AuthenticatorAttestationResponse
- Defined in:
- lib/turnkey_client/models/authenticator_attestation_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#attestation_object ⇒ Object
Returns the value of attribute attestation_object.
-
#authenticator_attachment ⇒ Object
Returns the value of attribute authenticator_attachment.
-
#client_data_json ⇒ Object
Returns the value of attribute client_data_json.
-
#transports ⇒ Object
Returns the value of attribute transports.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuthenticatorAttestationResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AuthenticatorAttestationResponse
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/turnkey_client/models/authenticator_attestation_response.rb', line 75 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TurnkeyClient::AuthenticatorAttestationResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TurnkeyClient::AuthenticatorAttestationResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'client_data_json') self.client_data_json = attributes[:'client_data_json'] end if attributes.key?(:'attestation_object') self.attestation_object = attributes[:'attestation_object'] end if attributes.key?(:'transports') if (value = attributes[:'transports']).is_a?(Array) self.transports = value end end if attributes.key?(:'authenticator_attachment') self. = attributes[:'authenticator_attachment'] end end |
Instance Attribute Details
#attestation_object ⇒ Object
Returns the value of attribute attestation_object.
18 19 20 |
# File 'lib/turnkey_client/models/authenticator_attestation_response.rb', line 18 def attestation_object @attestation_object end |
#authenticator_attachment ⇒ Object
Returns the value of attribute authenticator_attachment.
22 23 24 |
# File 'lib/turnkey_client/models/authenticator_attestation_response.rb', line 22 def @authenticator_attachment end |
#client_data_json ⇒ Object
Returns the value of attribute client_data_json.
16 17 18 |
# File 'lib/turnkey_client/models/authenticator_attestation_response.rb', line 16 def client_data_json @client_data_json end |
#transports ⇒ Object
Returns the value of attribute transports.
20 21 22 |
# File 'lib/turnkey_client/models/authenticator_attestation_response.rb', line 20 def transports @transports end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 |
# File 'lib/turnkey_client/models/authenticator_attestation_response.rb', line 47 def self.attribute_map { :'client_data_json' => :'clientDataJson', :'attestation_object' => :'attestationObject', :'transports' => :'transports', :'authenticator_attachment' => :'authenticatorAttachment' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
168 169 170 |
# File 'lib/turnkey_client/models/authenticator_attestation_response.rb', line 168 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 71 |
# File 'lib/turnkey_client/models/authenticator_attestation_response.rb', line 67 def self.openapi_nullable Set.new([ :'authenticator_attachment' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 |
# File 'lib/turnkey_client/models/authenticator_attestation_response.rb', line 57 def self.openapi_types { :'client_data_json' => :'Object', :'attestation_object' => :'Object', :'transports' => :'Object', :'authenticator_attachment' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
144 145 146 147 148 149 150 151 |
# File 'lib/turnkey_client/models/authenticator_attestation_response.rb', line 144 def ==(o) return true if self.equal?(o) self.class == o.class && client_data_json == o.client_data_json && attestation_object == o.attestation_object && transports == o.transports && == o. end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/turnkey_client/models/authenticator_attestation_response.rb', line 198 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TurnkeyClient.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/turnkey_client/models/authenticator_attestation_response.rb', line 267 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/turnkey_client/models/authenticator_attestation_response.rb', line 175 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) end end self end |
#eql?(o) ⇒ Boolean
155 156 157 |
# File 'lib/turnkey_client/models/authenticator_attestation_response.rb', line 155 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
161 162 163 |
# File 'lib/turnkey_client/models/authenticator_attestation_response.rb', line 161 def hash [client_data_json, attestation_object, transports, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/turnkey_client/models/authenticator_attestation_response.rb', line 109 def list_invalid_properties invalid_properties = Array.new if @client_data_json.nil? invalid_properties.push('invalid value for "client_data_json", client_data_json cannot be nil.') end if @attestation_object.nil? invalid_properties.push('invalid value for "attestation_object", attestation_object cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
243 244 245 |
# File 'lib/turnkey_client/models/authenticator_attestation_response.rb', line 243 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/turnkey_client/models/authenticator_attestation_response.rb', line 249 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
237 238 239 |
# File 'lib/turnkey_client/models/authenticator_attestation_response.rb', line 237 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
124 125 126 127 128 129 130 |
# File 'lib/turnkey_client/models/authenticator_attestation_response.rb', line 124 def valid? return false if @client_data_json.nil? return false if @attestation_object.nil? = EnumAttributeValidator.new('Object', ['cross-platform', 'platform']) return false unless .valid?(@authenticator_attachment) true end |