Class: TurnkeyClient::BroadcastingApi
- Inherits:
-
Object
- Object
- TurnkeyClient::BroadcastingApi
- Defined in:
- lib/turnkey_client/api/broadcasting_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#eth_send_transaction(body, opts = {}) ⇒ ActivityResponse
Submit a transaction intent for broadcasting.
-
#eth_send_transaction_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Submit a transaction intent for broadcasting.
-
#get_gas_usage(body, opts = {}) ⇒ GetGasUsageResponse
Get gas usage and limits.
-
#get_gas_usage_with_http_info(body, opts = {}) ⇒ Array<(GetGasUsageResponse, Integer, Hash)>
Get gas usage and limits.
-
#get_nonces(body, opts = {}) ⇒ GetNoncesResponse
Get nonces for an address.
-
#get_nonces_with_http_info(body, opts = {}) ⇒ Array<(GetNoncesResponse, Integer, Hash)>
Get nonces for an address.
-
#initialize(api_client = ApiClient.default) ⇒ BroadcastingApi
constructor
A new instance of BroadcastingApi.
-
#sol_send_transaction(body, opts = {}) ⇒ ActivityResponse
Submit a transaction intent for broadcasting.
-
#sol_send_transaction_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Submit a transaction intent for broadcasting.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ BroadcastingApi
Returns a new instance of BroadcastingApi.
15 16 17 |
# File 'lib/turnkey_client/api/broadcasting_api.rb', line 15 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
13 14 15 |
# File 'lib/turnkey_client/api/broadcasting_api.rb', line 13 def api_client @api_client end |
Instance Method Details
#eth_send_transaction(body, opts = {}) ⇒ ActivityResponse
Submit a transaction intent for broadcasting. Submit a transaction intent describing a transaction you would like to broadcast.
23 24 25 26 |
# File 'lib/turnkey_client/api/broadcasting_api.rb', line 23 def eth_send_transaction(body, opts = {}) data, _status_code, _headers = eth_send_transaction_with_http_info(body, opts) data end |
#eth_send_transaction_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Submit a transaction intent for broadcasting. Submit a transaction intent describing a transaction you would like to broadcast.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/turnkey_client/api/broadcasting_api.rb', line 33 def eth_send_transaction_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BroadcastingApi.eth_send_transaction ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling BroadcastingApi.eth_send_transaction" end # resource path local_var_path = '/public/v1/submit/eth_send_transaction' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: BroadcastingApi#eth_send_transaction\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_gas_usage(body, opts = {}) ⇒ GetGasUsageResponse
Get gas usage and limits. Get gas usage and gas limits for either the parent organization or a sub-organization.
81 82 83 84 |
# File 'lib/turnkey_client/api/broadcasting_api.rb', line 81 def get_gas_usage(body, opts = {}) data, _status_code, _headers = get_gas_usage_with_http_info(body, opts) data end |
#get_gas_usage_with_http_info(body, opts = {}) ⇒ Array<(GetGasUsageResponse, Integer, Hash)>
Get gas usage and limits. Get gas usage and gas limits for either the parent organization or a sub-organization.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/turnkey_client/api/broadcasting_api.rb', line 91 def get_gas_usage_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BroadcastingApi.get_gas_usage ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling BroadcastingApi.get_gas_usage" end # resource path local_var_path = '/public/v1/query/get_gas_usage' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'GetGasUsageResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: BroadcastingApi#get_gas_usage\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_nonces(body, opts = {}) ⇒ GetNoncesResponse
Get nonces for an address. Get nonce values for an address on a given network. Can fetch the standard on-chain nonce and/or the gas station nonce used for sponsored transactions.
139 140 141 142 |
# File 'lib/turnkey_client/api/broadcasting_api.rb', line 139 def get_nonces(body, opts = {}) data, _status_code, _headers = get_nonces_with_http_info(body, opts) data end |
#get_nonces_with_http_info(body, opts = {}) ⇒ Array<(GetNoncesResponse, Integer, Hash)>
Get nonces for an address. Get nonce values for an address on a given network. Can fetch the standard on-chain nonce and/or the gas station nonce used for sponsored transactions.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/turnkey_client/api/broadcasting_api.rb', line 149 def get_nonces_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BroadcastingApi.get_nonces ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling BroadcastingApi.get_nonces" end # resource path local_var_path = '/public/v1/query/get_nonces' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'GetNoncesResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: BroadcastingApi#get_nonces\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#sol_send_transaction(body, opts = {}) ⇒ ActivityResponse
Submit a transaction intent for broadcasting. Submit a transaction intent describing a transaction you would like to broadcast.
197 198 199 200 |
# File 'lib/turnkey_client/api/broadcasting_api.rb', line 197 def sol_send_transaction(body, opts = {}) data, _status_code, _headers = sol_send_transaction_with_http_info(body, opts) data end |
#sol_send_transaction_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Submit a transaction intent for broadcasting. Submit a transaction intent describing a transaction you would like to broadcast.
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/turnkey_client/api/broadcasting_api.rb', line 207 def sol_send_transaction_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BroadcastingApi.sol_send_transaction ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling BroadcastingApi.sol_send_transaction" end # resource path local_var_path = '/public/v1/submit/sol_send_transaction' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: BroadcastingApi#sol_send_transaction\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |