Class: TurnkeyClient::CreateTvcAppIntent
- Inherits:
-
Object
- Object
- TurnkeyClient::CreateTvcAppIntent
- Defined in:
- lib/turnkey_client/models/create_tvc_app_intent.rb
Instance Attribute Summary collapse
-
#enable_egress ⇒ Object
Enables network egress for this TVC app.
-
#manifest_set_id ⇒ Object
Unique identifier for an existing TVC operator set to use as the Manifest Set for this TVC application.
-
#manifest_set_params ⇒ Object
Returns the value of attribute manifest_set_params.
-
#name ⇒ Object
The name of the new TVC application.
-
#quorum_public_key ⇒ Object
Quorum public key to use for this application.
-
#share_set_id ⇒ Object
Unique identifier for an existing TVC operator set to use as the Share Set for this TVC application.
-
#share_set_params ⇒ Object
Returns the value of attribute share_set_params.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateTvcAppIntent
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreateTvcAppIntent
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 71 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TurnkeyClient::CreateTvcAppIntent` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TurnkeyClient::CreateTvcAppIntent`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'quorum_public_key') self.quorum_public_key = attributes[:'quorum_public_key'] end if attributes.key?(:'manifest_set_id') self.manifest_set_id = attributes[:'manifest_set_id'] end if attributes.key?(:'manifest_set_params') self.manifest_set_params = attributes[:'manifest_set_params'] end if attributes.key?(:'share_set_id') self.share_set_id = attributes[:'share_set_id'] end if attributes.key?(:'share_set_params') self.share_set_params = attributes[:'share_set_params'] end if attributes.key?(:'enable_egress') self.enable_egress = attributes[:'enable_egress'] end end |
Instance Attribute Details
#enable_egress ⇒ Object
Enables network egress for this TVC app. Default if not provided: false.
32 33 34 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 32 def enable_egress @enable_egress end |
#manifest_set_id ⇒ Object
Unique identifier for an existing TVC operator set to use as the Manifest Set for this TVC application. If left empty, a new Manifest Set configuration is required
22 23 24 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 22 def manifest_set_id @manifest_set_id end |
#manifest_set_params ⇒ Object
Returns the value of attribute manifest_set_params.
24 25 26 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 24 def manifest_set_params @manifest_set_params end |
#name ⇒ Object
The name of the new TVC application
16 17 18 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 16 def name @name end |
#quorum_public_key ⇒ Object
Quorum public key to use for this application
19 20 21 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 19 def quorum_public_key @quorum_public_key end |
#share_set_id ⇒ Object
Unique identifier for an existing TVC operator set to use as the Share Set for this TVC application. If left empty, a new Share Set configuration is required
27 28 29 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 27 def share_set_id @share_set_id end |
#share_set_params ⇒ Object
Returns the value of attribute share_set_params.
29 30 31 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 29 def share_set_params @share_set_params end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 35 def self.attribute_map { :'name' => :'name', :'quorum_public_key' => :'quorumPublicKey', :'manifest_set_id' => :'manifestSetId', :'manifest_set_params' => :'manifestSetParams', :'share_set_id' => :'shareSetId', :'share_set_params' => :'shareSetParams', :'enable_egress' => :'enableEgress' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
165 166 167 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 165 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 65 66 67 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 61 def self.openapi_nullable Set.new([ :'manifest_set_id', :'share_set_id', :'enable_egress' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 48 def self.openapi_types { :'name' => :'Object', :'quorum_public_key' => :'Object', :'manifest_set_id' => :'Object', :'manifest_set_params' => :'Object', :'share_set_id' => :'Object', :'share_set_params' => :'Object', :'enable_egress' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 138 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && quorum_public_key == o.quorum_public_key && manifest_set_id == o.manifest_set_id && manifest_set_params == o.manifest_set_params && share_set_id == o.share_set_id && share_set_params == o.share_set_params && enable_egress == o.enable_egress end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 195 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TurnkeyClient.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 264 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 172 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) end end self end |
#eql?(o) ⇒ Boolean
152 153 154 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 152 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
158 159 160 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 158 def hash [name, quorum_public_key, manifest_set_id, manifest_set_params, share_set_id, share_set_params, enable_egress].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 115 def list_invalid_properties invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @quorum_public_key.nil? invalid_properties.push('invalid value for "quorum_public_key", quorum_public_key cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
240 241 242 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 240 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 246 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
234 235 236 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 234 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
130 131 132 133 134 |
# File 'lib/turnkey_client/models/create_tvc_app_intent.rb', line 130 def valid? return false if @name.nil? return false if @quorum_public_key.nil? true end |