Class: TurnkeyClient::EmailAuthIntentV2

Inherits:
Object
  • Object
show all
Defined in:
lib/turnkey_client/models/email_auth_intent_v2.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EmailAuthIntentV2

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TurnkeyClient::EmailAuthIntentV2` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TurnkeyClient::EmailAuthIntentV2`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'target_public_key')
    self.target_public_key = attributes[:'target_public_key']
  end

  if attributes.key?(:'api_key_name')
    self.api_key_name = attributes[:'api_key_name']
  end

  if attributes.key?(:'expiration_seconds')
    self.expiration_seconds = attributes[:'expiration_seconds']
  end

  if attributes.key?(:'email_customization')
    self.email_customization = attributes[:'email_customization']
  end

  if attributes.key?(:'invalidate_existing')
    self.invalidate_existing = attributes[:'invalidate_existing']
  end
end

Instance Attribute Details

#api_key_nameObject

Optional human-readable name for an API Key. If none provided, default to Email Auth - <Timestamp>



22
23
24
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 22

def api_key_name
  @api_key_name
end

#emailObject

Email of the authenticating user.



16
17
18
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 16

def email
  @email
end

#email_customizationObject

Returns the value of attribute email_customization.



27
28
29
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 27

def email_customization
  @email_customization
end

#expiration_secondsObject

Expiration window (in seconds) indicating how long the API key is valid. If not provided, a default of 15 minutes will be used.



25
26
27
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 25

def expiration_seconds
  @expiration_seconds
end

#invalidate_existingObject

Invalidate all other previously generated Email Auth API keys



30
31
32
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 30

def invalidate_existing
  @invalidate_existing
end

#target_public_keyObject

Client-side public key generated by the user, to which the email auth bundle (credentials) will be encrypted.



19
20
21
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 19

def target_public_key
  @target_public_key
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 33

def self.attribute_map
  {
    :'email' => :'email',
    :'target_public_key' => :'targetPublicKey',
    :'api_key_name' => :'apiKeyName',
    :'expiration_seconds' => :'expirationSeconds',
    :'email_customization' => :'emailCustomization',
    :'invalidate_existing' => :'invalidateExisting'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



153
154
155
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 153

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



45
46
47
48
49
50
51
52
53
54
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 45

def self.openapi_types
  {
    :'email' => :'Object',
    :'target_public_key' => :'Object',
    :'api_key_name' => :'Object',
    :'expiration_seconds' => :'Object',
    :'email_customization' => :'Object',
    :'invalidate_existing' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



127
128
129
130
131
132
133
134
135
136
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 127

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      email == o.email &&
      target_public_key == o.target_public_key &&
      api_key_name == o.api_key_name &&
      expiration_seconds == o.expiration_seconds &&
      email_customization == o.email_customization &&
      invalidate_existing == o.invalidate_existing
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 183

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    TurnkeyClient.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 252

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 160

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


140
141
142
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 140

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



146
147
148
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 146

def hash
  [email, target_public_key, api_key_name, expiration_seconds, email_customization, invalidate_existing].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 104

def list_invalid_properties
  invalid_properties = Array.new
  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if @target_public_key.nil?
    invalid_properties.push('invalid value for "target_public_key", target_public_key cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



228
229
230
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 228

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 234

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



222
223
224
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 222

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



119
120
121
122
123
# File 'lib/turnkey_client/models/email_auth_intent_v2.rb', line 119

def valid?
  return false if @email.nil?
  return false if @target_public_key.nil?
  true
end