Class: TurnkeyClient::FiatOnRampCredential

Inherits:
Object
  • Object
show all
Defined in:
lib/turnkey_client/models/fiat_on_ramp_credential.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FiatOnRampCredential

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TurnkeyClient::FiatOnRampCredential` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TurnkeyClient::FiatOnRampCredential`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'fiat_onramp_credential_id')
    self.fiat_onramp_credential_id = attributes[:'fiat_onramp_credential_id']
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  end

  if attributes.key?(:'onramp_provider')
    self.onramp_provider = attributes[:'onramp_provider']
  end

  if attributes.key?(:'project_id')
    self.project_id = attributes[:'project_id']
  end

  if attributes.key?(:'publishable_api_key')
    self.publishable_api_key = attributes[:'publishable_api_key']
  end

  if attributes.key?(:'encrypted_secret_api_key')
    self.encrypted_secret_api_key = attributes[:'encrypted_secret_api_key']
  end

  if attributes.key?(:'encrypted_private_api_key')
    self.encrypted_private_api_key = attributes[:'encrypted_private_api_key']
  end

  if attributes.key?(:'sandbox_mode')
    self.sandbox_mode = attributes[:'sandbox_mode']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



38
39
40
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 38

def created_at
  @created_at
end

#encrypted_private_api_keyObject

Private API key for the on-ramp provider encrypted to our on-ramp encryption public key. Some providers, like Coinbase, require this additional key.



33
34
35
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 33

def encrypted_private_api_key
  @encrypted_private_api_key
end

#encrypted_secret_api_keyObject

Secret API key for the on-ramp provider encrypted to our on-ramp encryption public key.



30
31
32
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 30

def encrypted_secret_api_key
  @encrypted_secret_api_key
end

#fiat_onramp_credential_idObject

Unique identifier for a given Fiat On-Ramp Credential.



16
17
18
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 16

def fiat_onramp_credential_id
  @fiat_onramp_credential_id
end

#onramp_providerObject

Returns the value of attribute onramp_provider.



21
22
23
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 21

def onramp_provider
  @onramp_provider
end

#organization_idObject

Unique identifier for an Organization.



19
20
21
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 19

def organization_id
  @organization_id
end

#project_idObject

Project ID for the on-ramp provider. Some providers, like Coinbase, require this additional identifier.



24
25
26
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 24

def project_id
  @project_id
end

#publishable_api_keyObject

Publishable API key for the on-ramp provider.



27
28
29
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 27

def publishable_api_key
  @publishable_api_key
end

#sandbox_modeObject

If the on-ramp credential is a sandbox credential.



36
37
38
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 36

def sandbox_mode
  @sandbox_mode
end

#updated_atObject

Returns the value of attribute updated_at.



40
41
42
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 40

def updated_at
  @updated_at
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 43

def self.attribute_map
  {
    :'fiat_onramp_credential_id' => :'fiatOnrampCredentialId',
    :'organization_id' => :'organizationId',
    :'onramp_provider' => :'onrampProvider',
    :'project_id' => :'projectId',
    :'publishable_api_key' => :'publishableApiKey',
    :'encrypted_secret_api_key' => :'encryptedSecretApiKey',
    :'encrypted_private_api_key' => :'encryptedPrivateApiKey',
    :'sandbox_mode' => :'sandboxMode',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



218
219
220
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 218

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



75
76
77
78
79
80
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 75

def self.openapi_nullable
  Set.new([
    :'project_id',
    :'encrypted_private_api_key',
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 59

def self.openapi_types
  {
    :'fiat_onramp_credential_id' => :'Object',
    :'organization_id' => :'Object',
    :'onramp_provider' => :'Object',
    :'project_id' => :'Object',
    :'publishable_api_key' => :'Object',
    :'encrypted_secret_api_key' => :'Object',
    :'encrypted_private_api_key' => :'Object',
    :'sandbox_mode' => :'Object',
    :'created_at' => :'Object',
    :'updated_at' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 188

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      fiat_onramp_credential_id == o.fiat_onramp_credential_id &&
      organization_id == o.organization_id &&
      onramp_provider == o.onramp_provider &&
      project_id == o.project_id &&
      publishable_api_key == o.publishable_api_key &&
      encrypted_secret_api_key == o.encrypted_secret_api_key &&
      encrypted_private_api_key == o.encrypted_private_api_key &&
      sandbox_mode == o.sandbox_mode &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 248

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    TurnkeyClient.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 317

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 225

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


205
206
207
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 205

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



211
212
213
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 211

def hash
  [fiat_onramp_credential_id, organization_id, onramp_provider, project_id, publishable_api_key, encrypted_secret_api_key, encrypted_private_api_key, sandbox_mode, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 140

def list_invalid_properties
  invalid_properties = Array.new
  if @fiat_onramp_credential_id.nil?
    invalid_properties.push('invalid value for "fiat_onramp_credential_id", fiat_onramp_credential_id cannot be nil.')
  end

  if @organization_id.nil?
    invalid_properties.push('invalid value for "organization_id", organization_id cannot be nil.')
  end

  if @onramp_provider.nil?
    invalid_properties.push('invalid value for "onramp_provider", onramp_provider cannot be nil.')
  end

  if @publishable_api_key.nil?
    invalid_properties.push('invalid value for "publishable_api_key", publishable_api_key cannot be nil.')
  end

  if @encrypted_secret_api_key.nil?
    invalid_properties.push('invalid value for "encrypted_secret_api_key", encrypted_secret_api_key cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



293
294
295
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 293

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 299

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



287
288
289
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 287

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



175
176
177
178
179
180
181
182
183
184
# File 'lib/turnkey_client/models/fiat_on_ramp_credential.rb', line 175

def valid?
  return false if @fiat_onramp_credential_id.nil?
  return false if @organization_id.nil?
  return false if @onramp_provider.nil?
  return false if @publishable_api_key.nil?
  return false if @encrypted_secret_api_key.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end