Class: TurnkeyClient::IPAllowlistApi
- Inherits:
-
Object
- Object
- TurnkeyClient::IPAllowlistApi
- Defined in:
- lib/turnkey_client/api/ip_allowlist_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_ip_allowlist(body, opts = {}) ⇒ GetIpAllowlistResponse
Get IP Allowlist Get IP allowlist and rules for an organization.
-
#get_ip_allowlist_with_http_info(body, opts = {}) ⇒ Array<(GetIpAllowlistResponse, Integer, Hash)>
Get IP Allowlist Get IP allowlist and rules for an organization.
-
#initialize(api_client = ApiClient.default) ⇒ IPAllowlistApi
constructor
A new instance of IPAllowlistApi.
-
#remove_ip_allowlist(body, opts = {}) ⇒ ActivityResponse
Remove IP Allowlist Delete IP allowlist and all associated rules for organization or API key.
-
#remove_ip_allowlist_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Remove IP Allowlist Delete IP allowlist and all associated rules for organization or API key.
-
#set_ip_allowlist(body, opts = {}) ⇒ ActivityResponse
Set IP Allowlist Create or update IP allowlist and rules for organization or API key.
-
#set_ip_allowlist_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Set IP Allowlist Create or update IP allowlist and rules for organization or API key.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ IPAllowlistApi
Returns a new instance of IPAllowlistApi.
15 16 17 |
# File 'lib/turnkey_client/api/ip_allowlist_api.rb', line 15 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
13 14 15 |
# File 'lib/turnkey_client/api/ip_allowlist_api.rb', line 13 def api_client @api_client end |
Instance Method Details
#get_ip_allowlist(body, opts = {}) ⇒ GetIpAllowlistResponse
Get IP Allowlist Get IP allowlist and rules for an organization.
23 24 25 26 |
# File 'lib/turnkey_client/api/ip_allowlist_api.rb', line 23 def get_ip_allowlist(body, opts = {}) data, _status_code, _headers = get_ip_allowlist_with_http_info(body, opts) data end |
#get_ip_allowlist_with_http_info(body, opts = {}) ⇒ Array<(GetIpAllowlistResponse, Integer, Hash)>
Get IP Allowlist Get IP allowlist and rules for an organization.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/turnkey_client/api/ip_allowlist_api.rb', line 33 def get_ip_allowlist_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IPAllowlistApi.get_ip_allowlist ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling IPAllowlistApi.get_ip_allowlist" end # resource path local_var_path = '/public/v1/query/get_ip_allowlist' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'GetIpAllowlistResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: IPAllowlistApi#get_ip_allowlist\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#remove_ip_allowlist(body, opts = {}) ⇒ ActivityResponse
Remove IP Allowlist Delete IP allowlist and all associated rules for organization or API key. After removal, access will be determined by organization-level allowlist (for API keys) or allowed from all IPs (for organizations).
81 82 83 84 |
# File 'lib/turnkey_client/api/ip_allowlist_api.rb', line 81 def remove_ip_allowlist(body, opts = {}) data, _status_code, _headers = remove_ip_allowlist_with_http_info(body, opts) data end |
#remove_ip_allowlist_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Remove IP Allowlist Delete IP allowlist and all associated rules for organization or API key. After removal, access will be determined by organization-level allowlist (for API keys) or allowed from all IPs (for organizations).
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/turnkey_client/api/ip_allowlist_api.rb', line 91 def remove_ip_allowlist_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IPAllowlistApi.remove_ip_allowlist ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling IPAllowlistApi.remove_ip_allowlist" end # resource path local_var_path = '/public/v1/submit/remove_ip_allowlist' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: IPAllowlistApi#remove_ip_allowlist\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#set_ip_allowlist(body, opts = {}) ⇒ ActivityResponse
Set IP Allowlist Create or update IP allowlist and rules for organization or API key. The IP allowlist restricts API access to specific CIDR blocks. Organization-level allowlists apply to all API keys unless overridden by a key-specific allowlist.
139 140 141 142 |
# File 'lib/turnkey_client/api/ip_allowlist_api.rb', line 139 def set_ip_allowlist(body, opts = {}) data, _status_code, _headers = set_ip_allowlist_with_http_info(body, opts) data end |
#set_ip_allowlist_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Set IP Allowlist Create or update IP allowlist and rules for organization or API key. The IP allowlist restricts API access to specific CIDR blocks. Organization-level allowlists apply to all API keys unless overridden by a key-specific allowlist.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/turnkey_client/api/ip_allowlist_api.rb', line 149 def set_ip_allowlist_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IPAllowlistApi.set_ip_allowlist ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling IPAllowlistApi.set_ip_allowlist" end # resource path local_var_path = '/public/v1/submit/set_ip_allowlist' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: IPAllowlistApi#set_ip_allowlist\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |