Class: TurnkeyClient::Intent
- Inherits:
-
Object
- Object
- TurnkeyClient::Intent
- Defined in:
- lib/turnkey_client/models/intent.rb
Instance Attribute Summary collapse
-
#accept_invitation_intent ⇒ Object
Returns the value of attribute accept_invitation_intent.
-
#accept_invitation_intent_v2 ⇒ Object
Returns the value of attribute accept_invitation_intent_v2.
-
#activate_billing_tier_intent ⇒ Object
Returns the value of attribute activate_billing_tier_intent.
-
#approve_activity_intent ⇒ Object
Returns the value of attribute approve_activity_intent.
-
#create_api_keys_intent ⇒ Object
Returns the value of attribute create_api_keys_intent.
-
#create_api_only_users_intent ⇒ Object
Returns the value of attribute create_api_only_users_intent.
-
#create_authenticators_intent ⇒ Object
Returns the value of attribute create_authenticators_intent.
-
#create_authenticators_intent_v2 ⇒ Object
Returns the value of attribute create_authenticators_intent_v2.
-
#create_invitations_intent ⇒ Object
Returns the value of attribute create_invitations_intent.
-
#create_organization_intent ⇒ Object
Returns the value of attribute create_organization_intent.
-
#create_organization_intent_v2 ⇒ Object
Returns the value of attribute create_organization_intent_v2.
-
#create_policy_intent ⇒ Object
Returns the value of attribute create_policy_intent.
-
#create_policy_intent_v2 ⇒ Object
Returns the value of attribute create_policy_intent_v2.
-
#create_policy_intent_v3 ⇒ Object
Returns the value of attribute create_policy_intent_v3.
-
#create_private_key_tag_intent ⇒ Object
Returns the value of attribute create_private_key_tag_intent.
-
#create_private_keys_intent ⇒ Object
Returns the value of attribute create_private_keys_intent.
-
#create_private_keys_intent_v2 ⇒ Object
Returns the value of attribute create_private_keys_intent_v2.
-
#create_sub_organization_intent ⇒ Object
Returns the value of attribute create_sub_organization_intent.
-
#create_sub_organization_intent_v2 ⇒ Object
Returns the value of attribute create_sub_organization_intent_v2.
-
#create_sub_organization_intent_v3 ⇒ Object
Returns the value of attribute create_sub_organization_intent_v3.
-
#create_sub_organization_intent_v4 ⇒ Object
Returns the value of attribute create_sub_organization_intent_v4.
-
#create_user_tag_intent ⇒ Object
Returns the value of attribute create_user_tag_intent.
-
#create_users_intent ⇒ Object
Returns the value of attribute create_users_intent.
-
#create_users_intent_v2 ⇒ Object
Returns the value of attribute create_users_intent_v2.
-
#create_wallet_accounts_intent ⇒ Object
Returns the value of attribute create_wallet_accounts_intent.
-
#create_wallet_intent ⇒ Object
Returns the value of attribute create_wallet_intent.
-
#delete_api_keys_intent ⇒ Object
Returns the value of attribute delete_api_keys_intent.
-
#delete_authenticators_intent ⇒ Object
Returns the value of attribute delete_authenticators_intent.
-
#delete_invitation_intent ⇒ Object
Returns the value of attribute delete_invitation_intent.
-
#delete_organization_intent ⇒ Object
Returns the value of attribute delete_organization_intent.
-
#delete_payment_method_intent ⇒ Object
Returns the value of attribute delete_payment_method_intent.
-
#delete_policy_intent ⇒ Object
Returns the value of attribute delete_policy_intent.
-
#delete_private_key_tags_intent ⇒ Object
Returns the value of attribute delete_private_key_tags_intent.
-
#delete_user_tags_intent ⇒ Object
Returns the value of attribute delete_user_tags_intent.
-
#delete_users_intent ⇒ Object
Returns the value of attribute delete_users_intent.
-
#disable_private_key_intent ⇒ Object
Returns the value of attribute disable_private_key_intent.
-
#email_auth_intent ⇒ Object
Returns the value of attribute email_auth_intent.
-
#export_private_key_intent ⇒ Object
Returns the value of attribute export_private_key_intent.
-
#export_wallet_account_intent ⇒ Object
Returns the value of attribute export_wallet_account_intent.
-
#export_wallet_intent ⇒ Object
Returns the value of attribute export_wallet_intent.
-
#import_wallet_intent ⇒ Object
Returns the value of attribute import_wallet_intent.
-
#init_import_wallet_intent ⇒ Object
Returns the value of attribute init_import_wallet_intent.
-
#init_user_email_recovery_intent ⇒ Object
Returns the value of attribute init_user_email_recovery_intent.
-
#recover_user_intent ⇒ Object
Returns the value of attribute recover_user_intent.
-
#reject_activity_intent ⇒ Object
Returns the value of attribute reject_activity_intent.
-
#remove_organization_feature_intent ⇒ Object
Returns the value of attribute remove_organization_feature_intent.
-
#set_organization_feature_intent ⇒ Object
Returns the value of attribute set_organization_feature_intent.
-
#set_payment_method_intent ⇒ Object
Returns the value of attribute set_payment_method_intent.
-
#set_payment_method_intent_v2 ⇒ Object
Returns the value of attribute set_payment_method_intent_v2.
-
#sign_raw_payload_intent ⇒ Object
Returns the value of attribute sign_raw_payload_intent.
-
#sign_raw_payload_intent_v2 ⇒ Object
Returns the value of attribute sign_raw_payload_intent_v2.
-
#sign_transaction_intent ⇒ Object
Returns the value of attribute sign_transaction_intent.
-
#sign_transaction_intent_v2 ⇒ Object
Returns the value of attribute sign_transaction_intent_v2.
-
#update_allowed_origins_intent ⇒ Object
Returns the value of attribute update_allowed_origins_intent.
-
#update_policy_intent ⇒ Object
Returns the value of attribute update_policy_intent.
-
#update_private_key_tag_intent ⇒ Object
Returns the value of attribute update_private_key_tag_intent.
-
#update_root_quorum_intent ⇒ Object
Returns the value of attribute update_root_quorum_intent.
-
#update_user_intent ⇒ Object
Returns the value of attribute update_user_intent.
-
#update_user_tag_intent ⇒ Object
Returns the value of attribute update_user_tag_intent.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Intent
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Intent
Initializes the object
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 |
# File 'lib/turnkey_client/models/intent.rb', line 272 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TurnkeyClient::Intent` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TurnkeyClient::Intent`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'create_organization_intent') self.create_organization_intent = attributes[:'create_organization_intent'] end if attributes.key?(:'create_authenticators_intent') self.create_authenticators_intent = attributes[:'create_authenticators_intent'] end if attributes.key?(:'create_users_intent') self.create_users_intent = attributes[:'create_users_intent'] end if attributes.key?(:'create_private_keys_intent') self.create_private_keys_intent = attributes[:'create_private_keys_intent'] end if attributes.key?(:'sign_raw_payload_intent') self.sign_raw_payload_intent = attributes[:'sign_raw_payload_intent'] end if attributes.key?(:'create_invitations_intent') self.create_invitations_intent = attributes[:'create_invitations_intent'] end if attributes.key?(:'accept_invitation_intent') self.accept_invitation_intent = attributes[:'accept_invitation_intent'] end if attributes.key?(:'create_policy_intent') self.create_policy_intent = attributes[:'create_policy_intent'] end if attributes.key?(:'disable_private_key_intent') self.disable_private_key_intent = attributes[:'disable_private_key_intent'] end if attributes.key?(:'delete_users_intent') self.delete_users_intent = attributes[:'delete_users_intent'] end if attributes.key?(:'delete_authenticators_intent') self.delete_authenticators_intent = attributes[:'delete_authenticators_intent'] end if attributes.key?(:'delete_invitation_intent') self.delete_invitation_intent = attributes[:'delete_invitation_intent'] end if attributes.key?(:'delete_organization_intent') self.delete_organization_intent = attributes[:'delete_organization_intent'] end if attributes.key?(:'delete_policy_intent') self.delete_policy_intent = attributes[:'delete_policy_intent'] end if attributes.key?(:'create_user_tag_intent') self.create_user_tag_intent = attributes[:'create_user_tag_intent'] end if attributes.key?(:'delete_user_tags_intent') self. = attributes[:'delete_user_tags_intent'] end if attributes.key?(:'sign_transaction_intent') self.sign_transaction_intent = attributes[:'sign_transaction_intent'] end if attributes.key?(:'create_api_keys_intent') self.create_api_keys_intent = attributes[:'create_api_keys_intent'] end if attributes.key?(:'delete_api_keys_intent') self.delete_api_keys_intent = attributes[:'delete_api_keys_intent'] end if attributes.key?(:'approve_activity_intent') self.approve_activity_intent = attributes[:'approve_activity_intent'] end if attributes.key?(:'reject_activity_intent') self.reject_activity_intent = attributes[:'reject_activity_intent'] end if attributes.key?(:'create_private_key_tag_intent') self.create_private_key_tag_intent = attributes[:'create_private_key_tag_intent'] end if attributes.key?(:'delete_private_key_tags_intent') self. = attributes[:'delete_private_key_tags_intent'] end if attributes.key?(:'create_policy_intent_v2') self.create_policy_intent_v2 = attributes[:'create_policy_intent_v2'] end if attributes.key?(:'set_payment_method_intent') self.set_payment_method_intent = attributes[:'set_payment_method_intent'] end if attributes.key?(:'activate_billing_tier_intent') self.activate_billing_tier_intent = attributes[:'activate_billing_tier_intent'] end if attributes.key?(:'delete_payment_method_intent') self.delete_payment_method_intent = attributes[:'delete_payment_method_intent'] end if attributes.key?(:'create_policy_intent_v3') self.create_policy_intent_v3 = attributes[:'create_policy_intent_v3'] end if attributes.key?(:'create_api_only_users_intent') self.create_api_only_users_intent = attributes[:'create_api_only_users_intent'] end if attributes.key?(:'update_root_quorum_intent') self.update_root_quorum_intent = attributes[:'update_root_quorum_intent'] end if attributes.key?(:'update_user_tag_intent') self.update_user_tag_intent = attributes[:'update_user_tag_intent'] end if attributes.key?(:'update_private_key_tag_intent') self.update_private_key_tag_intent = attributes[:'update_private_key_tag_intent'] end if attributes.key?(:'create_authenticators_intent_v2') self.create_authenticators_intent_v2 = attributes[:'create_authenticators_intent_v2'] end if attributes.key?(:'accept_invitation_intent_v2') self.accept_invitation_intent_v2 = attributes[:'accept_invitation_intent_v2'] end if attributes.key?(:'create_organization_intent_v2') self.create_organization_intent_v2 = attributes[:'create_organization_intent_v2'] end if attributes.key?(:'create_users_intent_v2') self.create_users_intent_v2 = attributes[:'create_users_intent_v2'] end if attributes.key?(:'create_sub_organization_intent') self.create_sub_organization_intent = attributes[:'create_sub_organization_intent'] end if attributes.key?(:'create_sub_organization_intent_v2') self.create_sub_organization_intent_v2 = attributes[:'create_sub_organization_intent_v2'] end if attributes.key?(:'update_allowed_origins_intent') self.update_allowed_origins_intent = attributes[:'update_allowed_origins_intent'] end if attributes.key?(:'create_private_keys_intent_v2') self.create_private_keys_intent_v2 = attributes[:'create_private_keys_intent_v2'] end if attributes.key?(:'update_user_intent') self.update_user_intent = attributes[:'update_user_intent'] end if attributes.key?(:'update_policy_intent') self.update_policy_intent = attributes[:'update_policy_intent'] end if attributes.key?(:'set_payment_method_intent_v2') self.set_payment_method_intent_v2 = attributes[:'set_payment_method_intent_v2'] end if attributes.key?(:'create_sub_organization_intent_v3') self.create_sub_organization_intent_v3 = attributes[:'create_sub_organization_intent_v3'] end if attributes.key?(:'create_wallet_intent') self.create_wallet_intent = attributes[:'create_wallet_intent'] end if attributes.key?(:'create_wallet_accounts_intent') self.create_wallet_accounts_intent = attributes[:'create_wallet_accounts_intent'] end if attributes.key?(:'init_user_email_recovery_intent') self.init_user_email_recovery_intent = attributes[:'init_user_email_recovery_intent'] end if attributes.key?(:'recover_user_intent') self.recover_user_intent = attributes[:'recover_user_intent'] end if attributes.key?(:'set_organization_feature_intent') self.set_organization_feature_intent = attributes[:'set_organization_feature_intent'] end if attributes.key?(:'remove_organization_feature_intent') self.remove_organization_feature_intent = attributes[:'remove_organization_feature_intent'] end if attributes.key?(:'sign_raw_payload_intent_v2') self.sign_raw_payload_intent_v2 = attributes[:'sign_raw_payload_intent_v2'] end if attributes.key?(:'sign_transaction_intent_v2') self.sign_transaction_intent_v2 = attributes[:'sign_transaction_intent_v2'] end if attributes.key?(:'export_private_key_intent') self.export_private_key_intent = attributes[:'export_private_key_intent'] end if attributes.key?(:'export_wallet_intent') self.export_wallet_intent = attributes[:'export_wallet_intent'] end if attributes.key?(:'create_sub_organization_intent_v4') self.create_sub_organization_intent_v4 = attributes[:'create_sub_organization_intent_v4'] end if attributes.key?(:'email_auth_intent') self.email_auth_intent = attributes[:'email_auth_intent'] end if attributes.key?(:'export_wallet_account_intent') self.export_wallet_account_intent = attributes[:'export_wallet_account_intent'] end if attributes.key?(:'init_import_wallet_intent') self.init_import_wallet_intent = attributes[:'init_import_wallet_intent'] end if attributes.key?(:'import_wallet_intent') self.import_wallet_intent = attributes[:'import_wallet_intent'] end end |
Instance Attribute Details
#accept_invitation_intent ⇒ Object
Returns the value of attribute accept_invitation_intent.
28 29 30 |
# File 'lib/turnkey_client/models/intent.rb', line 28 def accept_invitation_intent @accept_invitation_intent end |
#accept_invitation_intent_v2 ⇒ Object
Returns the value of attribute accept_invitation_intent_v2.
82 83 84 |
# File 'lib/turnkey_client/models/intent.rb', line 82 def accept_invitation_intent_v2 @accept_invitation_intent_v2 end |
#activate_billing_tier_intent ⇒ Object
Returns the value of attribute activate_billing_tier_intent.
66 67 68 |
# File 'lib/turnkey_client/models/intent.rb', line 66 def activate_billing_tier_intent @activate_billing_tier_intent end |
#approve_activity_intent ⇒ Object
Returns the value of attribute approve_activity_intent.
54 55 56 |
# File 'lib/turnkey_client/models/intent.rb', line 54 def approve_activity_intent @approve_activity_intent end |
#create_api_keys_intent ⇒ Object
Returns the value of attribute create_api_keys_intent.
50 51 52 |
# File 'lib/turnkey_client/models/intent.rb', line 50 def create_api_keys_intent @create_api_keys_intent end |
#create_api_only_users_intent ⇒ Object
Returns the value of attribute create_api_only_users_intent.
72 73 74 |
# File 'lib/turnkey_client/models/intent.rb', line 72 def create_api_only_users_intent @create_api_only_users_intent end |
#create_authenticators_intent ⇒ Object
Returns the value of attribute create_authenticators_intent.
18 19 20 |
# File 'lib/turnkey_client/models/intent.rb', line 18 def create_authenticators_intent @create_authenticators_intent end |
#create_authenticators_intent_v2 ⇒ Object
Returns the value of attribute create_authenticators_intent_v2.
80 81 82 |
# File 'lib/turnkey_client/models/intent.rb', line 80 def create_authenticators_intent_v2 @create_authenticators_intent_v2 end |
#create_invitations_intent ⇒ Object
Returns the value of attribute create_invitations_intent.
26 27 28 |
# File 'lib/turnkey_client/models/intent.rb', line 26 def create_invitations_intent @create_invitations_intent end |
#create_organization_intent ⇒ Object
Returns the value of attribute create_organization_intent.
16 17 18 |
# File 'lib/turnkey_client/models/intent.rb', line 16 def create_organization_intent @create_organization_intent end |
#create_organization_intent_v2 ⇒ Object
Returns the value of attribute create_organization_intent_v2.
84 85 86 |
# File 'lib/turnkey_client/models/intent.rb', line 84 def create_organization_intent_v2 @create_organization_intent_v2 end |
#create_policy_intent ⇒ Object
Returns the value of attribute create_policy_intent.
30 31 32 |
# File 'lib/turnkey_client/models/intent.rb', line 30 def create_policy_intent @create_policy_intent end |
#create_policy_intent_v2 ⇒ Object
Returns the value of attribute create_policy_intent_v2.
62 63 64 |
# File 'lib/turnkey_client/models/intent.rb', line 62 def create_policy_intent_v2 @create_policy_intent_v2 end |
#create_policy_intent_v3 ⇒ Object
Returns the value of attribute create_policy_intent_v3.
70 71 72 |
# File 'lib/turnkey_client/models/intent.rb', line 70 def create_policy_intent_v3 @create_policy_intent_v3 end |
#create_private_key_tag_intent ⇒ Object
Returns the value of attribute create_private_key_tag_intent.
58 59 60 |
# File 'lib/turnkey_client/models/intent.rb', line 58 def create_private_key_tag_intent @create_private_key_tag_intent end |
#create_private_keys_intent ⇒ Object
Returns the value of attribute create_private_keys_intent.
22 23 24 |
# File 'lib/turnkey_client/models/intent.rb', line 22 def create_private_keys_intent @create_private_keys_intent end |
#create_private_keys_intent_v2 ⇒ Object
Returns the value of attribute create_private_keys_intent_v2.
94 95 96 |
# File 'lib/turnkey_client/models/intent.rb', line 94 def create_private_keys_intent_v2 @create_private_keys_intent_v2 end |
#create_sub_organization_intent ⇒ Object
Returns the value of attribute create_sub_organization_intent.
88 89 90 |
# File 'lib/turnkey_client/models/intent.rb', line 88 def create_sub_organization_intent @create_sub_organization_intent end |
#create_sub_organization_intent_v2 ⇒ Object
Returns the value of attribute create_sub_organization_intent_v2.
90 91 92 |
# File 'lib/turnkey_client/models/intent.rb', line 90 def create_sub_organization_intent_v2 @create_sub_organization_intent_v2 end |
#create_sub_organization_intent_v3 ⇒ Object
Returns the value of attribute create_sub_organization_intent_v3.
102 103 104 |
# File 'lib/turnkey_client/models/intent.rb', line 102 def create_sub_organization_intent_v3 @create_sub_organization_intent_v3 end |
#create_sub_organization_intent_v4 ⇒ Object
Returns the value of attribute create_sub_organization_intent_v4.
124 125 126 |
# File 'lib/turnkey_client/models/intent.rb', line 124 def create_sub_organization_intent_v4 @create_sub_organization_intent_v4 end |
#create_user_tag_intent ⇒ Object
Returns the value of attribute create_user_tag_intent.
44 45 46 |
# File 'lib/turnkey_client/models/intent.rb', line 44 def create_user_tag_intent @create_user_tag_intent end |
#create_users_intent ⇒ Object
Returns the value of attribute create_users_intent.
20 21 22 |
# File 'lib/turnkey_client/models/intent.rb', line 20 def create_users_intent @create_users_intent end |
#create_users_intent_v2 ⇒ Object
Returns the value of attribute create_users_intent_v2.
86 87 88 |
# File 'lib/turnkey_client/models/intent.rb', line 86 def create_users_intent_v2 @create_users_intent_v2 end |
#create_wallet_accounts_intent ⇒ Object
Returns the value of attribute create_wallet_accounts_intent.
106 107 108 |
# File 'lib/turnkey_client/models/intent.rb', line 106 def create_wallet_accounts_intent @create_wallet_accounts_intent end |
#create_wallet_intent ⇒ Object
Returns the value of attribute create_wallet_intent.
104 105 106 |
# File 'lib/turnkey_client/models/intent.rb', line 104 def create_wallet_intent @create_wallet_intent end |
#delete_api_keys_intent ⇒ Object
Returns the value of attribute delete_api_keys_intent.
52 53 54 |
# File 'lib/turnkey_client/models/intent.rb', line 52 def delete_api_keys_intent @delete_api_keys_intent end |
#delete_authenticators_intent ⇒ Object
Returns the value of attribute delete_authenticators_intent.
36 37 38 |
# File 'lib/turnkey_client/models/intent.rb', line 36 def delete_authenticators_intent @delete_authenticators_intent end |
#delete_invitation_intent ⇒ Object
Returns the value of attribute delete_invitation_intent.
38 39 40 |
# File 'lib/turnkey_client/models/intent.rb', line 38 def delete_invitation_intent @delete_invitation_intent end |
#delete_organization_intent ⇒ Object
Returns the value of attribute delete_organization_intent.
40 41 42 |
# File 'lib/turnkey_client/models/intent.rb', line 40 def delete_organization_intent @delete_organization_intent end |
#delete_payment_method_intent ⇒ Object
Returns the value of attribute delete_payment_method_intent.
68 69 70 |
# File 'lib/turnkey_client/models/intent.rb', line 68 def delete_payment_method_intent @delete_payment_method_intent end |
#delete_policy_intent ⇒ Object
Returns the value of attribute delete_policy_intent.
42 43 44 |
# File 'lib/turnkey_client/models/intent.rb', line 42 def delete_policy_intent @delete_policy_intent end |
#delete_private_key_tags_intent ⇒ Object
Returns the value of attribute delete_private_key_tags_intent.
60 61 62 |
# File 'lib/turnkey_client/models/intent.rb', line 60 def end |
#delete_user_tags_intent ⇒ Object
Returns the value of attribute delete_user_tags_intent.
46 47 48 |
# File 'lib/turnkey_client/models/intent.rb', line 46 def end |
#delete_users_intent ⇒ Object
Returns the value of attribute delete_users_intent.
34 35 36 |
# File 'lib/turnkey_client/models/intent.rb', line 34 def delete_users_intent @delete_users_intent end |
#disable_private_key_intent ⇒ Object
Returns the value of attribute disable_private_key_intent.
32 33 34 |
# File 'lib/turnkey_client/models/intent.rb', line 32 def disable_private_key_intent @disable_private_key_intent end |
#email_auth_intent ⇒ Object
Returns the value of attribute email_auth_intent.
126 127 128 |
# File 'lib/turnkey_client/models/intent.rb', line 126 def email_auth_intent @email_auth_intent end |
#export_private_key_intent ⇒ Object
Returns the value of attribute export_private_key_intent.
120 121 122 |
# File 'lib/turnkey_client/models/intent.rb', line 120 def export_private_key_intent @export_private_key_intent end |
#export_wallet_account_intent ⇒ Object
Returns the value of attribute export_wallet_account_intent.
128 129 130 |
# File 'lib/turnkey_client/models/intent.rb', line 128 def export_wallet_account_intent @export_wallet_account_intent end |
#export_wallet_intent ⇒ Object
Returns the value of attribute export_wallet_intent.
122 123 124 |
# File 'lib/turnkey_client/models/intent.rb', line 122 def export_wallet_intent @export_wallet_intent end |
#import_wallet_intent ⇒ Object
Returns the value of attribute import_wallet_intent.
132 133 134 |
# File 'lib/turnkey_client/models/intent.rb', line 132 def import_wallet_intent @import_wallet_intent end |
#init_import_wallet_intent ⇒ Object
Returns the value of attribute init_import_wallet_intent.
130 131 132 |
# File 'lib/turnkey_client/models/intent.rb', line 130 def init_import_wallet_intent @init_import_wallet_intent end |
#init_user_email_recovery_intent ⇒ Object
Returns the value of attribute init_user_email_recovery_intent.
108 109 110 |
# File 'lib/turnkey_client/models/intent.rb', line 108 def init_user_email_recovery_intent @init_user_email_recovery_intent end |
#recover_user_intent ⇒ Object
Returns the value of attribute recover_user_intent.
110 111 112 |
# File 'lib/turnkey_client/models/intent.rb', line 110 def recover_user_intent @recover_user_intent end |
#reject_activity_intent ⇒ Object
Returns the value of attribute reject_activity_intent.
56 57 58 |
# File 'lib/turnkey_client/models/intent.rb', line 56 def reject_activity_intent @reject_activity_intent end |
#remove_organization_feature_intent ⇒ Object
Returns the value of attribute remove_organization_feature_intent.
114 115 116 |
# File 'lib/turnkey_client/models/intent.rb', line 114 def remove_organization_feature_intent @remove_organization_feature_intent end |
#set_organization_feature_intent ⇒ Object
Returns the value of attribute set_organization_feature_intent.
112 113 114 |
# File 'lib/turnkey_client/models/intent.rb', line 112 def set_organization_feature_intent @set_organization_feature_intent end |
#set_payment_method_intent ⇒ Object
Returns the value of attribute set_payment_method_intent.
64 65 66 |
# File 'lib/turnkey_client/models/intent.rb', line 64 def set_payment_method_intent @set_payment_method_intent end |
#set_payment_method_intent_v2 ⇒ Object
Returns the value of attribute set_payment_method_intent_v2.
100 101 102 |
# File 'lib/turnkey_client/models/intent.rb', line 100 def set_payment_method_intent_v2 @set_payment_method_intent_v2 end |
#sign_raw_payload_intent ⇒ Object
Returns the value of attribute sign_raw_payload_intent.
24 25 26 |
# File 'lib/turnkey_client/models/intent.rb', line 24 def sign_raw_payload_intent @sign_raw_payload_intent end |
#sign_raw_payload_intent_v2 ⇒ Object
Returns the value of attribute sign_raw_payload_intent_v2.
116 117 118 |
# File 'lib/turnkey_client/models/intent.rb', line 116 def sign_raw_payload_intent_v2 @sign_raw_payload_intent_v2 end |
#sign_transaction_intent ⇒ Object
Returns the value of attribute sign_transaction_intent.
48 49 50 |
# File 'lib/turnkey_client/models/intent.rb', line 48 def sign_transaction_intent @sign_transaction_intent end |
#sign_transaction_intent_v2 ⇒ Object
Returns the value of attribute sign_transaction_intent_v2.
118 119 120 |
# File 'lib/turnkey_client/models/intent.rb', line 118 def sign_transaction_intent_v2 @sign_transaction_intent_v2 end |
#update_allowed_origins_intent ⇒ Object
Returns the value of attribute update_allowed_origins_intent.
92 93 94 |
# File 'lib/turnkey_client/models/intent.rb', line 92 def update_allowed_origins_intent @update_allowed_origins_intent end |
#update_policy_intent ⇒ Object
Returns the value of attribute update_policy_intent.
98 99 100 |
# File 'lib/turnkey_client/models/intent.rb', line 98 def update_policy_intent @update_policy_intent end |
#update_private_key_tag_intent ⇒ Object
Returns the value of attribute update_private_key_tag_intent.
78 79 80 |
# File 'lib/turnkey_client/models/intent.rb', line 78 def update_private_key_tag_intent @update_private_key_tag_intent end |
#update_root_quorum_intent ⇒ Object
Returns the value of attribute update_root_quorum_intent.
74 75 76 |
# File 'lib/turnkey_client/models/intent.rb', line 74 def update_root_quorum_intent @update_root_quorum_intent end |
#update_user_intent ⇒ Object
Returns the value of attribute update_user_intent.
96 97 98 |
# File 'lib/turnkey_client/models/intent.rb', line 96 def update_user_intent @update_user_intent end |
#update_user_tag_intent ⇒ Object
Returns the value of attribute update_user_tag_intent.
76 77 78 |
# File 'lib/turnkey_client/models/intent.rb', line 76 def update_user_tag_intent @update_user_tag_intent end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/turnkey_client/models/intent.rb', line 135 def self.attribute_map { :'create_organization_intent' => :'createOrganizationIntent', :'create_authenticators_intent' => :'createAuthenticatorsIntent', :'create_users_intent' => :'createUsersIntent', :'create_private_keys_intent' => :'createPrivateKeysIntent', :'sign_raw_payload_intent' => :'signRawPayloadIntent', :'create_invitations_intent' => :'createInvitationsIntent', :'accept_invitation_intent' => :'acceptInvitationIntent', :'create_policy_intent' => :'createPolicyIntent', :'disable_private_key_intent' => :'disablePrivateKeyIntent', :'delete_users_intent' => :'deleteUsersIntent', :'delete_authenticators_intent' => :'deleteAuthenticatorsIntent', :'delete_invitation_intent' => :'deleteInvitationIntent', :'delete_organization_intent' => :'deleteOrganizationIntent', :'delete_policy_intent' => :'deletePolicyIntent', :'create_user_tag_intent' => :'createUserTagIntent', :'delete_user_tags_intent' => :'deleteUserTagsIntent', :'sign_transaction_intent' => :'signTransactionIntent', :'create_api_keys_intent' => :'createApiKeysIntent', :'delete_api_keys_intent' => :'deleteApiKeysIntent', :'approve_activity_intent' => :'approveActivityIntent', :'reject_activity_intent' => :'rejectActivityIntent', :'create_private_key_tag_intent' => :'createPrivateKeyTagIntent', :'delete_private_key_tags_intent' => :'deletePrivateKeyTagsIntent', :'create_policy_intent_v2' => :'createPolicyIntentV2', :'set_payment_method_intent' => :'setPaymentMethodIntent', :'activate_billing_tier_intent' => :'activateBillingTierIntent', :'delete_payment_method_intent' => :'deletePaymentMethodIntent', :'create_policy_intent_v3' => :'createPolicyIntentV3', :'create_api_only_users_intent' => :'createApiOnlyUsersIntent', :'update_root_quorum_intent' => :'updateRootQuorumIntent', :'update_user_tag_intent' => :'updateUserTagIntent', :'update_private_key_tag_intent' => :'updatePrivateKeyTagIntent', :'create_authenticators_intent_v2' => :'createAuthenticatorsIntentV2', :'accept_invitation_intent_v2' => :'acceptInvitationIntentV2', :'create_organization_intent_v2' => :'createOrganizationIntentV2', :'create_users_intent_v2' => :'createUsersIntentV2', :'create_sub_organization_intent' => :'createSubOrganizationIntent', :'create_sub_organization_intent_v2' => :'createSubOrganizationIntentV2', :'update_allowed_origins_intent' => :'updateAllowedOriginsIntent', :'create_private_keys_intent_v2' => :'createPrivateKeysIntentV2', :'update_user_intent' => :'updateUserIntent', :'update_policy_intent' => :'updatePolicyIntent', :'set_payment_method_intent_v2' => :'setPaymentMethodIntentV2', :'create_sub_organization_intent_v3' => :'createSubOrganizationIntentV3', :'create_wallet_intent' => :'createWalletIntent', :'create_wallet_accounts_intent' => :'createWalletAccountsIntent', :'init_user_email_recovery_intent' => :'initUserEmailRecoveryIntent', :'recover_user_intent' => :'recoverUserIntent', :'set_organization_feature_intent' => :'setOrganizationFeatureIntent', :'remove_organization_feature_intent' => :'removeOrganizationFeatureIntent', :'sign_raw_payload_intent_v2' => :'signRawPayloadIntentV2', :'sign_transaction_intent_v2' => :'signTransactionIntentV2', :'export_private_key_intent' => :'exportPrivateKeyIntent', :'export_wallet_intent' => :'exportWalletIntent', :'create_sub_organization_intent_v4' => :'createSubOrganizationIntentV4', :'email_auth_intent' => :'emailAuthIntent', :'export_wallet_account_intent' => :'exportWalletAccountIntent', :'init_import_wallet_intent' => :'initImportWalletIntent', :'import_wallet_intent' => :'importWalletIntent' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
621 622 623 |
# File 'lib/turnkey_client/models/intent.rb', line 621 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
265 266 267 268 |
# File 'lib/turnkey_client/models/intent.rb', line 265 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/turnkey_client/models/intent.rb', line 200 def self.openapi_types { :'create_organization_intent' => :'Object', :'create_authenticators_intent' => :'Object', :'create_users_intent' => :'Object', :'create_private_keys_intent' => :'Object', :'sign_raw_payload_intent' => :'Object', :'create_invitations_intent' => :'Object', :'accept_invitation_intent' => :'Object', :'create_policy_intent' => :'Object', :'disable_private_key_intent' => :'Object', :'delete_users_intent' => :'Object', :'delete_authenticators_intent' => :'Object', :'delete_invitation_intent' => :'Object', :'delete_organization_intent' => :'Object', :'delete_policy_intent' => :'Object', :'create_user_tag_intent' => :'Object', :'delete_user_tags_intent' => :'Object', :'sign_transaction_intent' => :'Object', :'create_api_keys_intent' => :'Object', :'delete_api_keys_intent' => :'Object', :'approve_activity_intent' => :'Object', :'reject_activity_intent' => :'Object', :'create_private_key_tag_intent' => :'Object', :'delete_private_key_tags_intent' => :'Object', :'create_policy_intent_v2' => :'Object', :'set_payment_method_intent' => :'Object', :'activate_billing_tier_intent' => :'Object', :'delete_payment_method_intent' => :'Object', :'create_policy_intent_v3' => :'Object', :'create_api_only_users_intent' => :'Object', :'update_root_quorum_intent' => :'Object', :'update_user_tag_intent' => :'Object', :'update_private_key_tag_intent' => :'Object', :'create_authenticators_intent_v2' => :'Object', :'accept_invitation_intent_v2' => :'Object', :'create_organization_intent_v2' => :'Object', :'create_users_intent_v2' => :'Object', :'create_sub_organization_intent' => :'Object', :'create_sub_organization_intent_v2' => :'Object', :'update_allowed_origins_intent' => :'Object', :'create_private_keys_intent_v2' => :'Object', :'update_user_intent' => :'Object', :'update_policy_intent' => :'Object', :'set_payment_method_intent_v2' => :'Object', :'create_sub_organization_intent_v3' => :'Object', :'create_wallet_intent' => :'Object', :'create_wallet_accounts_intent' => :'Object', :'init_user_email_recovery_intent' => :'Object', :'recover_user_intent' => :'Object', :'set_organization_feature_intent' => :'Object', :'remove_organization_feature_intent' => :'Object', :'sign_raw_payload_intent_v2' => :'Object', :'sign_transaction_intent_v2' => :'Object', :'export_private_key_intent' => :'Object', :'export_wallet_intent' => :'Object', :'create_sub_organization_intent_v4' => :'Object', :'email_auth_intent' => :'Object', :'export_wallet_account_intent' => :'Object', :'init_import_wallet_intent' => :'Object', :'import_wallet_intent' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 |
# File 'lib/turnkey_client/models/intent.rb', line 542 def ==(o) return true if self.equal?(o) self.class == o.class && create_organization_intent == o.create_organization_intent && create_authenticators_intent == o.create_authenticators_intent && create_users_intent == o.create_users_intent && create_private_keys_intent == o.create_private_keys_intent && sign_raw_payload_intent == o.sign_raw_payload_intent && create_invitations_intent == o.create_invitations_intent && accept_invitation_intent == o.accept_invitation_intent && create_policy_intent == o.create_policy_intent && disable_private_key_intent == o.disable_private_key_intent && delete_users_intent == o.delete_users_intent && delete_authenticators_intent == o.delete_authenticators_intent && delete_invitation_intent == o.delete_invitation_intent && delete_organization_intent == o.delete_organization_intent && delete_policy_intent == o.delete_policy_intent && create_user_tag_intent == o.create_user_tag_intent && == o. && sign_transaction_intent == o.sign_transaction_intent && create_api_keys_intent == o.create_api_keys_intent && delete_api_keys_intent == o.delete_api_keys_intent && approve_activity_intent == o.approve_activity_intent && reject_activity_intent == o.reject_activity_intent && create_private_key_tag_intent == o.create_private_key_tag_intent && == o. && create_policy_intent_v2 == o.create_policy_intent_v2 && set_payment_method_intent == o.set_payment_method_intent && activate_billing_tier_intent == o.activate_billing_tier_intent && delete_payment_method_intent == o.delete_payment_method_intent && create_policy_intent_v3 == o.create_policy_intent_v3 && create_api_only_users_intent == o.create_api_only_users_intent && update_root_quorum_intent == o.update_root_quorum_intent && update_user_tag_intent == o.update_user_tag_intent && update_private_key_tag_intent == o.update_private_key_tag_intent && create_authenticators_intent_v2 == o.create_authenticators_intent_v2 && accept_invitation_intent_v2 == o.accept_invitation_intent_v2 && create_organization_intent_v2 == o.create_organization_intent_v2 && create_users_intent_v2 == o.create_users_intent_v2 && create_sub_organization_intent == o.create_sub_organization_intent && create_sub_organization_intent_v2 == o.create_sub_organization_intent_v2 && update_allowed_origins_intent == o.update_allowed_origins_intent && create_private_keys_intent_v2 == o.create_private_keys_intent_v2 && update_user_intent == o.update_user_intent && update_policy_intent == o.update_policy_intent && set_payment_method_intent_v2 == o.set_payment_method_intent_v2 && create_sub_organization_intent_v3 == o.create_sub_organization_intent_v3 && create_wallet_intent == o.create_wallet_intent && create_wallet_accounts_intent == o.create_wallet_accounts_intent && init_user_email_recovery_intent == o.init_user_email_recovery_intent && recover_user_intent == o.recover_user_intent && set_organization_feature_intent == o.set_organization_feature_intent && remove_organization_feature_intent == o.remove_organization_feature_intent && sign_raw_payload_intent_v2 == o.sign_raw_payload_intent_v2 && sign_transaction_intent_v2 == o.sign_transaction_intent_v2 && export_private_key_intent == o.export_private_key_intent && export_wallet_intent == o.export_wallet_intent && create_sub_organization_intent_v4 == o.create_sub_organization_intent_v4 && email_auth_intent == o.email_auth_intent && export_wallet_account_intent == o.export_wallet_account_intent && init_import_wallet_intent == o.init_import_wallet_intent && import_wallet_intent == o.import_wallet_intent end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 |
# File 'lib/turnkey_client/models/intent.rb', line 651 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TurnkeyClient.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
720 721 722 723 724 725 726 727 728 729 730 731 732 |
# File 'lib/turnkey_client/models/intent.rb', line 720 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 |
# File 'lib/turnkey_client/models/intent.rb', line 628 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) end end self end |
#eql?(o) ⇒ Boolean
608 609 610 |
# File 'lib/turnkey_client/models/intent.rb', line 608 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
614 615 616 |
# File 'lib/turnkey_client/models/intent.rb', line 614 def hash [create_organization_intent, create_authenticators_intent, create_users_intent, create_private_keys_intent, sign_raw_payload_intent, create_invitations_intent, accept_invitation_intent, create_policy_intent, disable_private_key_intent, delete_users_intent, delete_authenticators_intent, delete_invitation_intent, delete_organization_intent, delete_policy_intent, create_user_tag_intent, , sign_transaction_intent, create_api_keys_intent, delete_api_keys_intent, approve_activity_intent, reject_activity_intent, create_private_key_tag_intent, , create_policy_intent_v2, set_payment_method_intent, activate_billing_tier_intent, delete_payment_method_intent, create_policy_intent_v3, create_api_only_users_intent, update_root_quorum_intent, update_user_tag_intent, update_private_key_tag_intent, create_authenticators_intent_v2, accept_invitation_intent_v2, create_organization_intent_v2, create_users_intent_v2, create_sub_organization_intent, create_sub_organization_intent_v2, update_allowed_origins_intent, create_private_keys_intent_v2, update_user_intent, update_policy_intent, set_payment_method_intent_v2, create_sub_organization_intent_v3, create_wallet_intent, create_wallet_accounts_intent, init_user_email_recovery_intent, recover_user_intent, set_organization_feature_intent, remove_organization_feature_intent, sign_raw_payload_intent_v2, sign_transaction_intent_v2, export_private_key_intent, export_wallet_intent, create_sub_organization_intent_v4, email_auth_intent, export_wallet_account_intent, init_import_wallet_intent, import_wallet_intent].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
524 525 526 527 528 529 530 531 |
# File 'lib/turnkey_client/models/intent.rb', line 524 def list_invalid_properties invalid_properties = Array.new if @create_organization_intent.nil? invalid_properties.push('invalid value for "create_organization_intent", create_organization_intent cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
696 697 698 |
# File 'lib/turnkey_client/models/intent.rb', line 696 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
702 703 704 705 706 707 708 709 710 711 712 713 714 |
# File 'lib/turnkey_client/models/intent.rb', line 702 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
690 691 692 |
# File 'lib/turnkey_client/models/intent.rb', line 690 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
535 536 537 538 |
# File 'lib/turnkey_client/models/intent.rb', line 535 def valid? return false if @create_organization_intent.nil? true end |