Class: TurnkeyClient::OnRampApi
- Inherits:
-
Object
- Object
- TurnkeyClient::OnRampApi
- Defined in:
- lib/turnkey_client/api/on_ramp_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_fiat_on_ramp_credential(body, opts = {}) ⇒ ActivityResponse
Create a Fiat On Ramp Credential Create a fiat on ramp provider credential.
-
#create_fiat_on_ramp_credential_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Create a Fiat On Ramp Credential Create a fiat on ramp provider credential.
-
#delete_fiat_on_ramp_credential(body, opts = {}) ⇒ ActivityResponse
Delete a Fiat On Ramp Credential Delete a fiat on ramp provider credential.
-
#delete_fiat_on_ramp_credential_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Delete a Fiat On Ramp Credential Delete a fiat on ramp provider credential.
-
#get_on_ramp_transaction_status(body, opts = {}) ⇒ GetOnRampTransactionStatusResponse
Get On Ramp transaction status Get the status of an on ramp transaction.
-
#get_on_ramp_transaction_status_with_http_info(body, opts = {}) ⇒ Array<(GetOnRampTransactionStatusResponse, Integer, Hash)>
Get On Ramp transaction status Get the status of an on ramp transaction.
-
#init_fiat_on_ramp(body, opts = {}) ⇒ ActivityResponse
Init fiat on ramp Initiate a fiat on ramp flow.
-
#init_fiat_on_ramp_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Init fiat on ramp Initiate a fiat on ramp flow.
-
#initialize(api_client = ApiClient.default) ⇒ OnRampApi
constructor
A new instance of OnRampApi.
-
#list_fiat_on_ramp_credentials(body, opts = {}) ⇒ ListFiatOnRampCredentialsResponse
List Fiat On Ramp Credentials List all fiat on ramp provider credentials within an organization.
-
#list_fiat_on_ramp_credentials_with_http_info(body, opts = {}) ⇒ Array<(ListFiatOnRampCredentialsResponse, Integer, Hash)>
List Fiat On Ramp Credentials List all fiat on ramp provider credentials within an organization.
-
#update_fiat_on_ramp_credential(body, opts = {}) ⇒ ActivityResponse
Update a Fiat On Ramp Credential Update a fiat on ramp provider credential.
-
#update_fiat_on_ramp_credential_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Update a Fiat On Ramp Credential Update a fiat on ramp provider credential.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
13 14 15 |
# File 'lib/turnkey_client/api/on_ramp_api.rb', line 13 def api_client @api_client end |
Instance Method Details
#create_fiat_on_ramp_credential(body, opts = {}) ⇒ ActivityResponse
Create a Fiat On Ramp Credential Create a fiat on ramp provider credential
23 24 25 26 |
# File 'lib/turnkey_client/api/on_ramp_api.rb', line 23 def create_fiat_on_ramp_credential(body, opts = {}) data, _status_code, _headers = create_fiat_on_ramp_credential_with_http_info(body, opts) data end |
#create_fiat_on_ramp_credential_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Create a Fiat On Ramp Credential Create a fiat on ramp provider credential
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/turnkey_client/api/on_ramp_api.rb', line 33 def create_fiat_on_ramp_credential_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OnRampApi.create_fiat_on_ramp_credential ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling OnRampApi.create_fiat_on_ramp_credential" end # resource path local_var_path = '/public/v1/submit/create_fiat_on_ramp_credential' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: OnRampApi#create_fiat_on_ramp_credential\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_fiat_on_ramp_credential(body, opts = {}) ⇒ ActivityResponse
Delete a Fiat On Ramp Credential Delete a fiat on ramp provider credential
81 82 83 84 |
# File 'lib/turnkey_client/api/on_ramp_api.rb', line 81 def delete_fiat_on_ramp_credential(body, opts = {}) data, _status_code, _headers = delete_fiat_on_ramp_credential_with_http_info(body, opts) data end |
#delete_fiat_on_ramp_credential_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Delete a Fiat On Ramp Credential Delete a fiat on ramp provider credential
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/turnkey_client/api/on_ramp_api.rb', line 91 def delete_fiat_on_ramp_credential_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OnRampApi.delete_fiat_on_ramp_credential ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling OnRampApi.delete_fiat_on_ramp_credential" end # resource path local_var_path = '/public/v1/submit/delete_fiat_on_ramp_credential' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: OnRampApi#delete_fiat_on_ramp_credential\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_on_ramp_transaction_status(body, opts = {}) ⇒ GetOnRampTransactionStatusResponse
Get On Ramp transaction status Get the status of an on ramp transaction.
139 140 141 142 |
# File 'lib/turnkey_client/api/on_ramp_api.rb', line 139 def get_on_ramp_transaction_status(body, opts = {}) data, _status_code, _headers = get_on_ramp_transaction_status_with_http_info(body, opts) data end |
#get_on_ramp_transaction_status_with_http_info(body, opts = {}) ⇒ Array<(GetOnRampTransactionStatusResponse, Integer, Hash)>
Get On Ramp transaction status Get the status of an on ramp transaction.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/turnkey_client/api/on_ramp_api.rb', line 149 def get_on_ramp_transaction_status_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OnRampApi.get_on_ramp_transaction_status ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling OnRampApi.get_on_ramp_transaction_status" end # resource path local_var_path = '/public/v1/query/get_onramp_transaction_status' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'GetOnRampTransactionStatusResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: OnRampApi#get_on_ramp_transaction_status\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#init_fiat_on_ramp(body, opts = {}) ⇒ ActivityResponse
Init fiat on ramp Initiate a fiat on ramp flow.
197 198 199 200 |
# File 'lib/turnkey_client/api/on_ramp_api.rb', line 197 def init_fiat_on_ramp(body, opts = {}) data, _status_code, _headers = init_fiat_on_ramp_with_http_info(body, opts) data end |
#init_fiat_on_ramp_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Init fiat on ramp Initiate a fiat on ramp flow.
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/turnkey_client/api/on_ramp_api.rb', line 207 def init_fiat_on_ramp_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OnRampApi.init_fiat_on_ramp ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling OnRampApi.init_fiat_on_ramp" end # resource path local_var_path = '/public/v1/submit/init_fiat_on_ramp' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: OnRampApi#init_fiat_on_ramp\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_fiat_on_ramp_credentials(body, opts = {}) ⇒ ListFiatOnRampCredentialsResponse
List Fiat On Ramp Credentials List all fiat on ramp provider credentials within an organization.
255 256 257 258 |
# File 'lib/turnkey_client/api/on_ramp_api.rb', line 255 def list_fiat_on_ramp_credentials(body, opts = {}) data, _status_code, _headers = list_fiat_on_ramp_credentials_with_http_info(body, opts) data end |
#list_fiat_on_ramp_credentials_with_http_info(body, opts = {}) ⇒ Array<(ListFiatOnRampCredentialsResponse, Integer, Hash)>
List Fiat On Ramp Credentials List all fiat on ramp provider credentials within an organization.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/turnkey_client/api/on_ramp_api.rb', line 265 def list_fiat_on_ramp_credentials_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OnRampApi.list_fiat_on_ramp_credentials ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling OnRampApi.list_fiat_on_ramp_credentials" end # resource path local_var_path = '/public/v1/query/list_fiat_on_ramp_credentials' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ListFiatOnRampCredentialsResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: OnRampApi#list_fiat_on_ramp_credentials\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_fiat_on_ramp_credential(body, opts = {}) ⇒ ActivityResponse
Update a Fiat On Ramp Credential Update a fiat on ramp provider credential
313 314 315 316 |
# File 'lib/turnkey_client/api/on_ramp_api.rb', line 313 def update_fiat_on_ramp_credential(body, opts = {}) data, _status_code, _headers = update_fiat_on_ramp_credential_with_http_info(body, opts) data end |
#update_fiat_on_ramp_credential_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Update a Fiat On Ramp Credential Update a fiat on ramp provider credential
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/turnkey_client/api/on_ramp_api.rb', line 323 def update_fiat_on_ramp_credential_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OnRampApi.update_fiat_on_ramp_credential ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling OnRampApi.update_fiat_on_ramp_credential" end # resource path local_var_path = '/public/v1/submit/update_fiat_on_ramp_credential' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: OnRampApi#update_fiat_on_ramp_credential\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |