Class: TurnkeyClient::OrganizationsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/turnkey_client/api/organizations_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ OrganizationsApi

Returns a new instance of OrganizationsApi.



15
16
17
# File 'lib/turnkey_client/api/organizations_api.rb', line 15

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



13
14
15
# File 'lib/turnkey_client/api/organizations_api.rb', line 13

def api_client
  @api_client
end

Instance Method Details

#create_sub_organization(body, opts = {}) ⇒ ActivityResponse

Create sub-organization Create a new sub-organization.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



23
24
25
26
# File 'lib/turnkey_client/api/organizations_api.rb', line 23

def create_sub_organization(body, opts = {})
  data, _status_code, _headers = create_sub_organization_with_http_info(body, opts)
  data
end

#create_sub_organization_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>

Create sub-organization Create a new sub-organization.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ActivityResponse, Integer, Hash)>)

    ActivityResponse data, response status code and response headers



33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/turnkey_client/api/organizations_api.rb', line 33

def create_sub_organization_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationsApi.create_sub_organization ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationsApi.create_sub_organization"
  end
  # resource path
  local_var_path = '/public/v1/submit/create_sub_organization'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(body) 

  return_type = opts[:return_type] || 'ActivityResponse' 

  auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type)

  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationsApi#create_sub_organization\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_webhook_endpoint(body, opts = {}) ⇒ ActivityResponse

Create webhook endpoint Create a webhook endpoint for an organization.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



81
82
83
84
# File 'lib/turnkey_client/api/organizations_api.rb', line 81

def create_webhook_endpoint(body, opts = {})
  data, _status_code, _headers = create_webhook_endpoint_with_http_info(body, opts)
  data
end

#create_webhook_endpoint_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>

Create webhook endpoint Create a webhook endpoint for an organization.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ActivityResponse, Integer, Hash)>)

    ActivityResponse data, response status code and response headers



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/turnkey_client/api/organizations_api.rb', line 91

def create_webhook_endpoint_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationsApi.create_webhook_endpoint ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationsApi.create_webhook_endpoint"
  end
  # resource path
  local_var_path = '/public/v1/submit/create_webhook_endpoint'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(body) 

  return_type = opts[:return_type] || 'ActivityResponse' 

  auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type)

  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationsApi#create_webhook_endpoint\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_sub_organization(body, opts = {}) ⇒ ActivityResponse

Delete sub-organization Delete a sub-organization.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



139
140
141
142
# File 'lib/turnkey_client/api/organizations_api.rb', line 139

def delete_sub_organization(body, opts = {})
  data, _status_code, _headers = delete_sub_organization_with_http_info(body, opts)
  data
end

#delete_sub_organization_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>

Delete sub-organization Delete a sub-organization.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ActivityResponse, Integer, Hash)>)

    ActivityResponse data, response status code and response headers



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/turnkey_client/api/organizations_api.rb', line 149

def delete_sub_organization_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationsApi.delete_sub_organization ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationsApi.delete_sub_organization"
  end
  # resource path
  local_var_path = '/public/v1/submit/delete_sub_organization'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(body) 

  return_type = opts[:return_type] || 'ActivityResponse' 

  auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type)

  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationsApi#delete_sub_organization\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_webhook_endpoint(body, opts = {}) ⇒ ActivityResponse

Delete webhook endpoint Delete a webhook endpoint for an organization.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



197
198
199
200
# File 'lib/turnkey_client/api/organizations_api.rb', line 197

def delete_webhook_endpoint(body, opts = {})
  data, _status_code, _headers = delete_webhook_endpoint_with_http_info(body, opts)
  data
end

#delete_webhook_endpoint_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>

Delete webhook endpoint Delete a webhook endpoint for an organization.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ActivityResponse, Integer, Hash)>)

    ActivityResponse data, response status code and response headers



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/turnkey_client/api/organizations_api.rb', line 207

def delete_webhook_endpoint_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationsApi.delete_webhook_endpoint ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationsApi.delete_webhook_endpoint"
  end
  # resource path
  local_var_path = '/public/v1/submit/delete_webhook_endpoint'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(body) 

  return_type = opts[:return_type] || 'ActivityResponse' 

  auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type)

  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationsApi#delete_webhook_endpoint\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_organization_configs(body, opts = {}) ⇒ GetOrganizationConfigsResponse

Get configs Get quorum settings and features for an organization.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



255
256
257
258
# File 'lib/turnkey_client/api/organizations_api.rb', line 255

def get_organization_configs(body, opts = {})
  data, _status_code, _headers = get_organization_configs_with_http_info(body, opts)
  data
end

#get_organization_configs_with_http_info(body, opts = {}) ⇒ Array<(GetOrganizationConfigsResponse, Integer, Hash)>

Get configs Get quorum settings and features for an organization.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/turnkey_client/api/organizations_api.rb', line 265

def get_organization_configs_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationsApi.get_organization_configs ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationsApi.get_organization_configs"
  end
  # resource path
  local_var_path = '/public/v1/query/get_organization_configs'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(body) 

  return_type = opts[:return_type] || 'GetOrganizationConfigsResponse' 

  auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type)

  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationsApi#get_organization_configs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_sub_org_ids(body, opts = {}) ⇒ GetSubOrgIdsResponse

Get sub-organizations Get all suborg IDs associated given a parent org ID and an optional filter.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



313
314
315
316
# File 'lib/turnkey_client/api/organizations_api.rb', line 313

def get_sub_org_ids(body, opts = {})
  data, _status_code, _headers = get_sub_org_ids_with_http_info(body, opts)
  data
end

#get_sub_org_ids_with_http_info(body, opts = {}) ⇒ Array<(GetSubOrgIdsResponse, Integer, Hash)>

Get sub-organizations Get all suborg IDs associated given a parent org ID and an optional filter.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(GetSubOrgIdsResponse, Integer, Hash)>)

    GetSubOrgIdsResponse data, response status code and response headers



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/turnkey_client/api/organizations_api.rb', line 323

def get_sub_org_ids_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationsApi.get_sub_org_ids ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationsApi.get_sub_org_ids"
  end
  # resource path
  local_var_path = '/public/v1/query/list_suborgs'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(body) 

  return_type = opts[:return_type] || 'GetSubOrgIdsResponse' 

  auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type)

  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationsApi#get_sub_org_ids\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_verified_sub_org_ids(body, opts = {}) ⇒ GetVerifiedSubOrgIdsResponse

Get verified sub-organizations Get all email or phone verified suborg IDs associated given a parent org ID.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



371
372
373
374
# File 'lib/turnkey_client/api/organizations_api.rb', line 371

def get_verified_sub_org_ids(body, opts = {})
  data, _status_code, _headers = get_verified_sub_org_ids_with_http_info(body, opts)
  data
end

#get_verified_sub_org_ids_with_http_info(body, opts = {}) ⇒ Array<(GetVerifiedSubOrgIdsResponse, Integer, Hash)>

Get verified sub-organizations Get all email or phone verified suborg IDs associated given a parent org ID.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/turnkey_client/api/organizations_api.rb', line 381

def get_verified_sub_org_ids_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationsApi.get_verified_sub_org_ids ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationsApi.get_verified_sub_org_ids"
  end
  # resource path
  local_var_path = '/public/v1/query/list_verified_suborgs'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(body) 

  return_type = opts[:return_type] || 'GetVerifiedSubOrgIdsResponse' 

  auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type)

  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationsApi#get_verified_sub_org_ids\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_webhook_endpoints(body, opts = {}) ⇒ ListWebhookEndpointsResponse

List webhook endpoints List webhook endpoints within an organization.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



429
430
431
432
# File 'lib/turnkey_client/api/organizations_api.rb', line 429

def list_webhook_endpoints(body, opts = {})
  data, _status_code, _headers = list_webhook_endpoints_with_http_info(body, opts)
  data
end

#list_webhook_endpoints_with_http_info(body, opts = {}) ⇒ Array<(ListWebhookEndpointsResponse, Integer, Hash)>

List webhook endpoints List webhook endpoints within an organization.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
# File 'lib/turnkey_client/api/organizations_api.rb', line 439

def list_webhook_endpoints_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationsApi.list_webhook_endpoints ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationsApi.list_webhook_endpoints"
  end
  # resource path
  local_var_path = '/public/v1/query/list_webhook_endpoints'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(body) 

  return_type = opts[:return_type] || 'ListWebhookEndpointsResponse' 

  auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type)

  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationsApi#list_webhook_endpoints\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_organization_name(body, opts = {}) ⇒ ActivityResponse

Update organization name Update the name of an organization.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



487
488
489
490
# File 'lib/turnkey_client/api/organizations_api.rb', line 487

def update_organization_name(body, opts = {})
  data, _status_code, _headers = update_organization_name_with_http_info(body, opts)
  data
end

#update_organization_name_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>

Update organization name Update the name of an organization.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ActivityResponse, Integer, Hash)>)

    ActivityResponse data, response status code and response headers



497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'lib/turnkey_client/api/organizations_api.rb', line 497

def update_organization_name_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationsApi.update_organization_name ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationsApi.update_organization_name"
  end
  # resource path
  local_var_path = '/public/v1/submit/update_organization_name'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(body) 

  return_type = opts[:return_type] || 'ActivityResponse' 

  auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type)

  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationsApi#update_organization_name\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_root_quorum(body, opts = {}) ⇒ ActivityResponse

Update root quorum Set the threshold and members of the root quorum. This activity must be approved by the current root quorum.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



545
546
547
548
# File 'lib/turnkey_client/api/organizations_api.rb', line 545

def update_root_quorum(body, opts = {})
  data, _status_code, _headers = update_root_quorum_with_http_info(body, opts)
  data
end

#update_root_quorum_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>

Update root quorum Set the threshold and members of the root quorum. This activity must be approved by the current root quorum.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ActivityResponse, Integer, Hash)>)

    ActivityResponse data, response status code and response headers



555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
# File 'lib/turnkey_client/api/organizations_api.rb', line 555

def update_root_quorum_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationsApi.update_root_quorum ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationsApi.update_root_quorum"
  end
  # resource path
  local_var_path = '/public/v1/submit/update_root_quorum'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(body) 

  return_type = opts[:return_type] || 'ActivityResponse' 

  auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type)

  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationsApi#update_root_quorum\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_webhook_endpoint(body, opts = {}) ⇒ ActivityResponse

Update webhook endpoint Update a webhook endpoint for an organization.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



603
604
605
606
# File 'lib/turnkey_client/api/organizations_api.rb', line 603

def update_webhook_endpoint(body, opts = {})
  data, _status_code, _headers = update_webhook_endpoint_with_http_info(body, opts)
  data
end

#update_webhook_endpoint_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>

Update webhook endpoint Update a webhook endpoint for an organization.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ActivityResponse, Integer, Hash)>)

    ActivityResponse data, response status code and response headers



613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
# File 'lib/turnkey_client/api/organizations_api.rb', line 613

def update_webhook_endpoint_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationsApi.update_webhook_endpoint ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationsApi.update_webhook_endpoint"
  end
  # resource path
  local_var_path = '/public/v1/submit/update_webhook_endpoint'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(body) 

  return_type = opts[:return_type] || 'ActivityResponse' 

  auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type)

  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationsApi#update_webhook_endpoint\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end