Class: TurnkeyClient::PrivateKeysApi
- Inherits:
-
Object
- Object
- TurnkeyClient::PrivateKeysApi
- Defined in:
- lib/turnkey_client/api/private_keys_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_private_keys(body, opts = {}) ⇒ ActivityResponse
Create Private Keys Create new Private Keys.
-
#create_private_keys_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Create Private Keys Create new Private Keys.
-
#export_private_key(body, opts = {}) ⇒ ActivityResponse
Export Private Key Exports a Private Key.
-
#export_private_key_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Export Private Key Exports a Private Key.
-
#get_private_key(body, opts = {}) ⇒ GetPrivateKeyResponse
Get Private Key Get details about a Private Key.
-
#get_private_key_with_http_info(body, opts = {}) ⇒ Array<(GetPrivateKeyResponse, Integer, Hash)>
Get Private Key Get details about a Private Key.
-
#get_private_keys(body, opts = {}) ⇒ GetPrivateKeysResponse
List Private Keys List all Private Keys within an Organization.
-
#get_private_keys_with_http_info(body, opts = {}) ⇒ Array<(GetPrivateKeysResponse, Integer, Hash)>
List Private Keys List all Private Keys within an Organization.
-
#initialize(api_client = ApiClient.default) ⇒ PrivateKeysApi
constructor
A new instance of PrivateKeysApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ PrivateKeysApi
Returns a new instance of PrivateKeysApi.
16 17 18 |
# File 'lib/turnkey_client/api/private_keys_api.rb', line 16 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
14 15 16 |
# File 'lib/turnkey_client/api/private_keys_api.rb', line 14 def api_client @api_client end |
Instance Method Details
#create_private_keys(body, opts = {}) ⇒ ActivityResponse
Create Private Keys Create new Private Keys
24 25 26 27 |
# File 'lib/turnkey_client/api/private_keys_api.rb', line 24 def create_private_keys(body, opts = {}) data, _status_code, _headers = create_private_keys_with_http_info(body, opts) data end |
#create_private_keys_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Create Private Keys Create new Private Keys
34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/turnkey_client/api/private_keys_api.rb', line 34 def create_private_keys_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PrivateKeysApi.create_private_keys ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling PrivateKeysApi.create_private_keys" end # resource path local_var_path = '/public/v1/submit/create_private_keys' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: PrivateKeysApi#create_private_keys\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#export_private_key(body, opts = {}) ⇒ ActivityResponse
Export Private Key Exports a Private Key
82 83 84 85 |
# File 'lib/turnkey_client/api/private_keys_api.rb', line 82 def export_private_key(body, opts = {}) data, _status_code, _headers = export_private_key_with_http_info(body, opts) data end |
#export_private_key_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Export Private Key Exports a Private Key
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/turnkey_client/api/private_keys_api.rb', line 92 def export_private_key_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PrivateKeysApi.export_private_key ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling PrivateKeysApi.export_private_key" end # resource path local_var_path = '/public/v1/submit/export_private_key' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: PrivateKeysApi#export_private_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_private_key(body, opts = {}) ⇒ GetPrivateKeyResponse
Get Private Key Get details about a Private Key
140 141 142 143 |
# File 'lib/turnkey_client/api/private_keys_api.rb', line 140 def get_private_key(body, opts = {}) data, _status_code, _headers = get_private_key_with_http_info(body, opts) data end |
#get_private_key_with_http_info(body, opts = {}) ⇒ Array<(GetPrivateKeyResponse, Integer, Hash)>
Get Private Key Get details about a Private Key
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/turnkey_client/api/private_keys_api.rb', line 150 def get_private_key_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PrivateKeysApi.get_private_key ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling PrivateKeysApi.get_private_key" end # resource path local_var_path = '/public/v1/query/get_private_key' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'GetPrivateKeyResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: PrivateKeysApi#get_private_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_private_keys(body, opts = {}) ⇒ GetPrivateKeysResponse
List Private Keys List all Private Keys within an Organization
198 199 200 201 |
# File 'lib/turnkey_client/api/private_keys_api.rb', line 198 def get_private_keys(body, opts = {}) data, _status_code, _headers = get_private_keys_with_http_info(body, opts) data end |
#get_private_keys_with_http_info(body, opts = {}) ⇒ Array<(GetPrivateKeysResponse, Integer, Hash)>
List Private Keys List all Private Keys within an Organization
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/turnkey_client/api/private_keys_api.rb', line 208 def get_private_keys_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PrivateKeysApi.get_private_keys ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling PrivateKeysApi.get_private_keys" end # resource path local_var_path = '/public/v1/query/list_private_keys' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'GetPrivateKeysResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: PrivateKeysApi#get_private_keys\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |