Class: TurnkeyClient::SendTransactionsApi
- Inherits:
-
Object
- Object
- TurnkeyClient::SendTransactionsApi
- Defined in:
- lib/turnkey_client/api/send_transactions_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_send_transaction_status(body, opts = {}) ⇒ GetSendTransactionStatusResponse
Get send transaction status Get the status of a send transaction request.
-
#get_send_transaction_status_with_http_info(body, opts = {}) ⇒ Array<(GetSendTransactionStatusResponse, Integer, Hash)>
Get send transaction status Get the status of a send transaction request.
-
#initialize(api_client = ApiClient.default) ⇒ SendTransactionsApi
constructor
A new instance of SendTransactionsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ SendTransactionsApi
Returns a new instance of SendTransactionsApi.
15 16 17 |
# File 'lib/turnkey_client/api/send_transactions_api.rb', line 15 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
13 14 15 |
# File 'lib/turnkey_client/api/send_transactions_api.rb', line 13 def api_client @api_client end |
Instance Method Details
#get_send_transaction_status(body, opts = {}) ⇒ GetSendTransactionStatusResponse
Get send transaction status Get the status of a send transaction request.
23 24 25 26 |
# File 'lib/turnkey_client/api/send_transactions_api.rb', line 23 def get_send_transaction_status(body, opts = {}) data, _status_code, _headers = get_send_transaction_status_with_http_info(body, opts) data end |
#get_send_transaction_status_with_http_info(body, opts = {}) ⇒ Array<(GetSendTransactionStatusResponse, Integer, Hash)>
Get send transaction status Get the status of a send transaction request.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/turnkey_client/api/send_transactions_api.rb', line 33 def get_send_transaction_status_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SendTransactionsApi.get_send_transaction_status ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling SendTransactionsApi.get_send_transaction_status" end # resource path local_var_path = '/public/v1/query/get_send_transaction_status' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'GetSendTransactionStatusResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: SendTransactionsApi#get_send_transaction_status\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |