Class: TurnkeyClient::SessionsApi
- Inherits:
-
Object
- Object
- TurnkeyClient::SessionsApi
- Defined in:
- lib/turnkey_client/api/sessions_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_read_only_session(body, opts = {}) ⇒ ActivityResponse
Create read only session Create a read only session for a user (valid for 1 hour).
-
#create_read_only_session_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Create read only session Create a read only session for a user (valid for 1 hour).
-
#create_read_write_session(body, opts = {}) ⇒ ActivityResponse
Create read write session Create a read write session for a user.
-
#create_read_write_session_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Create read write session Create a read write session for a user.
-
#get_whoami(body, opts = {}) ⇒ GetWhoamiResponse
Who am I? Get basic information about your current API or WebAuthN user and their organization.
-
#get_whoami_with_http_info(body, opts = {}) ⇒ Array<(GetWhoamiResponse, Integer, Hash)>
Who am I? Get basic information about your current API or WebAuthN user and their organization.
-
#initialize(api_client = ApiClient.default) ⇒ SessionsApi
constructor
A new instance of SessionsApi.
-
#oauth_login(body, opts = {}) ⇒ ActivityResponse
Login with Oauth Create an Oauth session for a user.
-
#oauth_login_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Login with Oauth Create an Oauth session for a user.
-
#otp_login(body, opts = {}) ⇒ ActivityResponse
Login with OTP Create an OTP session for a user.
-
#otp_login_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Login with OTP Create an OTP session for a user.
-
#stamp_login(body, opts = {}) ⇒ ActivityResponse
Login with a stamp Create a session for a user through stamping client side (API key, wallet client, or passkey client).
-
#stamp_login_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Login with a stamp Create a session for a user through stamping client side (API key, wallet client, or passkey client).
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ SessionsApi
Returns a new instance of SessionsApi.
15 16 17 |
# File 'lib/turnkey_client/api/sessions_api.rb', line 15 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
13 14 15 |
# File 'lib/turnkey_client/api/sessions_api.rb', line 13 def api_client @api_client end |
Instance Method Details
#create_read_only_session(body, opts = {}) ⇒ ActivityResponse
Create read only session Create a read only session for a user (valid for 1 hour).
23 24 25 26 |
# File 'lib/turnkey_client/api/sessions_api.rb', line 23 def create_read_only_session(body, opts = {}) data, _status_code, _headers = create_read_only_session_with_http_info(body, opts) data end |
#create_read_only_session_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Create read only session Create a read only session for a user (valid for 1 hour).
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/turnkey_client/api/sessions_api.rb', line 33 def create_read_only_session_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SessionsApi.create_read_only_session ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling SessionsApi.create_read_only_session" end # resource path local_var_path = '/public/v1/submit/create_read_only_session' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: SessionsApi#create_read_only_session\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_read_write_session(body, opts = {}) ⇒ ActivityResponse
Create read write session Create a read write session for a user.
81 82 83 84 |
# File 'lib/turnkey_client/api/sessions_api.rb', line 81 def create_read_write_session(body, opts = {}) data, _status_code, _headers = create_read_write_session_with_http_info(body, opts) data end |
#create_read_write_session_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Create read write session Create a read write session for a user.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/turnkey_client/api/sessions_api.rb', line 91 def create_read_write_session_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SessionsApi.create_read_write_session ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling SessionsApi.create_read_write_session" end # resource path local_var_path = '/public/v1/submit/create_read_write_session' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: SessionsApi#create_read_write_session\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_whoami(body, opts = {}) ⇒ GetWhoamiResponse
Who am I? Get basic information about your current API or WebAuthN user and their organization. Affords sub-organization look ups via parent organization for WebAuthN or API key users.
139 140 141 142 |
# File 'lib/turnkey_client/api/sessions_api.rb', line 139 def get_whoami(body, opts = {}) data, _status_code, _headers = get_whoami_with_http_info(body, opts) data end |
#get_whoami_with_http_info(body, opts = {}) ⇒ Array<(GetWhoamiResponse, Integer, Hash)>
Who am I? Get basic information about your current API or WebAuthN user and their organization. Affords sub-organization look ups via parent organization for WebAuthN or API key users.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/turnkey_client/api/sessions_api.rb', line 149 def get_whoami_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SessionsApi.get_whoami ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling SessionsApi.get_whoami" end # resource path local_var_path = '/public/v1/query/whoami' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'GetWhoamiResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: SessionsApi#get_whoami\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#oauth_login(body, opts = {}) ⇒ ActivityResponse
Login with Oauth Create an Oauth session for a user.
197 198 199 200 |
# File 'lib/turnkey_client/api/sessions_api.rb', line 197 def oauth_login(body, opts = {}) data, _status_code, _headers = oauth_login_with_http_info(body, opts) data end |
#oauth_login_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Login with Oauth Create an Oauth session for a user.
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/turnkey_client/api/sessions_api.rb', line 207 def oauth_login_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SessionsApi.oauth_login ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling SessionsApi.oauth_login" end # resource path local_var_path = '/public/v1/submit/oauth_login' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: SessionsApi#oauth_login\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#otp_login(body, opts = {}) ⇒ ActivityResponse
Login with OTP Create an OTP session for a user.
255 256 257 258 |
# File 'lib/turnkey_client/api/sessions_api.rb', line 255 def otp_login(body, opts = {}) data, _status_code, _headers = otp_login_with_http_info(body, opts) data end |
#otp_login_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Login with OTP Create an OTP session for a user.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/turnkey_client/api/sessions_api.rb', line 265 def otp_login_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SessionsApi.otp_login ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling SessionsApi.otp_login" end # resource path local_var_path = '/public/v1/submit/otp_login' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: SessionsApi#otp_login\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#stamp_login(body, opts = {}) ⇒ ActivityResponse
Login with a stamp Create a session for a user through stamping client side (API key, wallet client, or passkey client).
313 314 315 316 |
# File 'lib/turnkey_client/api/sessions_api.rb', line 313 def stamp_login(body, opts = {}) data, _status_code, _headers = stamp_login_with_http_info(body, opts) data end |
#stamp_login_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Login with a stamp Create a session for a user through stamping client side (API key, wallet client, or passkey client).
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/turnkey_client/api/sessions_api.rb', line 323 def stamp_login_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SessionsApi.stamp_login ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling SessionsApi.stamp_login" end # resource path local_var_path = '/public/v1/submit/stamp_login' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: SessionsApi#stamp_login\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |