Class: TurnkeyClient::SparkClaimPackage
- Inherits:
-
Object
- Object
- TurnkeyClient::SparkClaimPackage
- Defined in:
- lib/turnkey_client/models/spark_claim_package.rb
Instance Attribute Summary collapse
-
#leaves ⇒ Object
Leaves being claimed.
-
#operator_recipients ⇒ Object
Operators that will receive Shamir shares.
-
#sender_identity_public_key ⇒ Object
Sender’s compressed secp256k1 identity public key (hex-encoded, 33 bytes).
-
#threshold ⇒ Object
Shamir threshold for reconstructing the per-leaf claim secret.
-
#transfer_id ⇒ Object
Spark transfer identifier (UUID).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SparkClaimPackage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ SparkClaimPackage
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 60 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TurnkeyClient::SparkClaimPackage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TurnkeyClient::SparkClaimPackage`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'leaves') if (value = attributes[:'leaves']).is_a?(Array) self.leaves = value end end if attributes.key?(:'threshold') self.threshold = attributes[:'threshold'] end if attributes.key?(:'operator_recipients') if (value = attributes[:'operator_recipients']).is_a?(Array) self.operator_recipients = value end end if attributes.key?(:'transfer_id') self.transfer_id = attributes[:'transfer_id'] end if attributes.key?(:'sender_identity_public_key') self.sender_identity_public_key = attributes[:'sender_identity_public_key'] end end |
Instance Attribute Details
#leaves ⇒ Object
Leaves being claimed.
16 17 18 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 16 def leaves @leaves end |
#operator_recipients ⇒ Object
Operators that will receive Shamir shares.
22 23 24 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 22 def operator_recipients @operator_recipients end |
#sender_identity_public_key ⇒ Object
Sender’s compressed secp256k1 identity public key (hex-encoded, 33 bytes). Used to verify the per-leaf sender_signature fields.
28 29 30 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 28 def sender_identity_public_key @sender_identity_public_key end |
#threshold ⇒ Object
Shamir threshold for reconstructing the per-leaf claim secret.
19 20 21 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 19 def threshold @threshold end |
#transfer_id ⇒ Object
Spark transfer identifier (UUID). Used together with each leaf’s sender_signature to verify the sender bound this ciphertext to this transfer.
25 26 27 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 25 def transfer_id @transfer_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 31 def self.attribute_map { :'leaves' => :'leaves', :'threshold' => :'threshold', :'operator_recipients' => :'operatorRecipients', :'transfer_id' => :'transferId', :'sender_identity_public_key' => :'senderIdentityPublicKey' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
163 164 165 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 163 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
53 54 55 56 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 53 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 48 49 50 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 42 def self.openapi_types { :'leaves' => :'Object', :'threshold' => :'Object', :'operator_recipients' => :'Object', :'transfer_id' => :'Object', :'sender_identity_public_key' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
138 139 140 141 142 143 144 145 146 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 138 def ==(o) return true if self.equal?(o) self.class == o.class && leaves == o.leaves && threshold == o.threshold && operator_recipients == o.operator_recipients && transfer_id == o.transfer_id && sender_identity_public_key == o.sender_identity_public_key end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 193 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TurnkeyClient.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 262 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 170 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) end end self end |
#eql?(o) ⇒ Boolean
150 151 152 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 150 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
156 157 158 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 156 def hash [leaves, threshold, operator_recipients, transfer_id, sender_identity_public_key].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 100 def list_invalid_properties invalid_properties = Array.new if @leaves.nil? invalid_properties.push('invalid value for "leaves", leaves cannot be nil.') end if @threshold.nil? invalid_properties.push('invalid value for "threshold", threshold cannot be nil.') end if @operator_recipients.nil? invalid_properties.push('invalid value for "operator_recipients", operator_recipients cannot be nil.') end if @transfer_id.nil? invalid_properties.push('invalid value for "transfer_id", transfer_id cannot be nil.') end if @sender_identity_public_key.nil? invalid_properties.push('invalid value for "sender_identity_public_key", sender_identity_public_key cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
238 239 240 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 238 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 244 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
232 233 234 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 232 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
127 128 129 130 131 132 133 134 |
# File 'lib/turnkey_client/models/spark_claim_package.rb', line 127 def valid? return false if @leaves.nil? return false if @threshold.nil? return false if @operator_recipients.nil? return false if @transfer_id.nil? return false if @sender_identity_public_key.nil? true end |