Class: TurnkeyClient::TvcApp
- Inherits:
-
Object
- Object
- TurnkeyClient::TvcApp
- Defined in:
- lib/turnkey_client/models/tvc_app.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#enable_egress ⇒ Object
Whether or not this TVC App has network egress enabled.
-
#id ⇒ Object
Unique Identifier for this TVC App.
-
#live_deployment_id ⇒ Object
The deployment currently designated to receive traffic.
-
#manifest_set ⇒ Object
Returns the value of attribute manifest_set.
-
#name ⇒ Object
Name for this TVC App.
-
#organization_id ⇒ Object
Unique Identifier of the Organization for this TVC App.
-
#public_domain ⇒ Object
The public domain for ingress to this TVC App (in the format "app-<ID>.turnkey.cloud").
-
#quorum_public_key ⇒ Object
Public key for the Quorum Key associated with this TVC App.
-
#share_set ⇒ Object
Returns the value of attribute share_set.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TvcApp
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ TvcApp
Initializes the object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 87 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TurnkeyClient::TvcApp` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TurnkeyClient::TvcApp`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'organization_id') self.organization_id = attributes[:'organization_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'quorum_public_key') self.quorum_public_key = attributes[:'quorum_public_key'] end if attributes.key?(:'manifest_set') self.manifest_set = attributes[:'manifest_set'] end if attributes.key?(:'share_set') self.share_set = attributes[:'share_set'] end if attributes.key?(:'enable_egress') self.enable_egress = attributes[:'enable_egress'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'live_deployment_id') self.live_deployment_id = attributes[:'live_deployment_id'] end if attributes.key?(:'public_domain') self.public_domain = attributes[:'public_domain'] end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
34 35 36 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 34 def created_at @created_at end |
#enable_egress ⇒ Object
Whether or not this TVC App has network egress enabled.
32 33 34 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 32 def enable_egress @enable_egress end |
#id ⇒ Object
Unique Identifier for this TVC App.
16 17 18 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 16 def id @id end |
#live_deployment_id ⇒ Object
The deployment currently designated to receive traffic. Null if no deployment for this app is deployed.
39 40 41 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 39 def live_deployment_id @live_deployment_id end |
#manifest_set ⇒ Object
Returns the value of attribute manifest_set.
27 28 29 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 27 def manifest_set @manifest_set end |
#name ⇒ Object
Name for this TVC App.
22 23 24 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 22 def name @name end |
#organization_id ⇒ Object
Unique Identifier of the Organization for this TVC App
19 20 21 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 19 def organization_id @organization_id end |
#public_domain ⇒ Object
The public domain for ingress to this TVC App (in the format "app-<ID>.turnkey.cloud").
42 43 44 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 42 def public_domain @public_domain end |
#quorum_public_key ⇒ Object
Public key for the Quorum Key associated with this TVC App
25 26 27 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 25 def quorum_public_key @quorum_public_key end |
#share_set ⇒ Object
Returns the value of attribute share_set.
29 30 31 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 29 def share_set @share_set end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
36 37 38 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 36 def updated_at @updated_at end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 45 def self.attribute_map { :'id' => :'id', :'organization_id' => :'organizationId', :'name' => :'name', :'quorum_public_key' => :'quorumPublicKey', :'manifest_set' => :'manifestSet', :'share_set' => :'shareSet', :'enable_egress' => :'enableEgress', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt', :'live_deployment_id' => :'liveDeploymentId', :'public_domain' => :'publicDomain' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
241 242 243 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 241 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
79 80 81 82 83 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 79 def self.openapi_nullable Set.new([ :'live_deployment_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 62 def self.openapi_types { :'id' => :'Object', :'organization_id' => :'Object', :'name' => :'Object', :'quorum_public_key' => :'Object', :'manifest_set' => :'Object', :'share_set' => :'Object', :'enable_egress' => :'Object', :'created_at' => :'Object', :'updated_at' => :'Object', :'live_deployment_id' => :'Object', :'public_domain' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 210 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && organization_id == o.organization_id && name == o.name && quorum_public_key == o.quorum_public_key && manifest_set == o.manifest_set && share_set == o.share_set && enable_egress == o.enable_egress && created_at == o.created_at && updated_at == o.updated_at && live_deployment_id == o.live_deployment_id && public_domain == o.public_domain end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 271 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TurnkeyClient.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 340 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 248 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) end end self end |
#eql?(o) ⇒ Boolean
228 229 230 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 228 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
234 235 236 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 234 def hash [id, organization_id, name, quorum_public_key, manifest_set, share_set, enable_egress, created_at, updated_at, live_deployment_id, public_domain].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 147 def list_invalid_properties invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @organization_id.nil? invalid_properties.push('invalid value for "organization_id", organization_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @quorum_public_key.nil? invalid_properties.push('invalid value for "quorum_public_key", quorum_public_key cannot be nil.') end if @manifest_set.nil? invalid_properties.push('invalid value for "manifest_set", manifest_set cannot be nil.') end if @share_set.nil? invalid_properties.push('invalid value for "share_set", share_set cannot be nil.') end if @enable_egress.nil? invalid_properties.push('invalid value for "enable_egress", enable_egress cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end if @public_domain.nil? invalid_properties.push('invalid value for "public_domain", public_domain cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
316 317 318 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 316 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 322 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
310 311 312 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 310 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/turnkey_client/models/tvc_app.rb', line 194 def valid? return false if @id.nil? return false if @organization_id.nil? return false if @name.nil? return false if @quorum_public_key.nil? return false if @manifest_set.nil? return false if @share_set.nil? return false if @enable_egress.nil? return false if @created_at.nil? return false if @updated_at.nil? return false if @public_domain.nil? true end |