Class: TurnkeyClient::UpdateAuthProxyConfigIntent
- Inherits:
-
Object
- Object
- TurnkeyClient::UpdateAuthProxyConfigIntent
- Defined in:
- lib/turnkey_client/models/update_auth_proxy_config_intent.rb
Instance Attribute Summary collapse
-
#allowed_auth_methods ⇒ Object
Updated list of allowed proxy authentication methods.
-
#allowed_origins ⇒ Object
Updated list of allowed origins for CORS.
-
#email_auth_template_id ⇒ Object
Template ID for email-auth messages.
-
#email_customization_params ⇒ Object
Returns the value of attribute email_customization_params.
-
#otp_alphanumeric ⇒ Object
Enable alphanumeric OTP codes.
-
#otp_expiration_seconds ⇒ Object
OTP code lifetime in seconds.
-
#otp_length ⇒ Object
Desired OTP code length (6–9).
-
#otp_template_id ⇒ Object
Template ID for OTP SMS messages.
-
#reply_to_email_address ⇒ Object
Custom reply-to address for auth-related emails.
-
#send_from_email_address ⇒ Object
Custom ‘from’ address for auth-related emails.
-
#send_from_email_sender_name ⇒ Object
Custom ‘from’ email sender for auth-related emails.
-
#session_expiration_seconds ⇒ Object
Session lifetime in seconds.
-
#sms_customization_params ⇒ Object
Returns the value of attribute sms_customization_params.
-
#verification_token_expiration_seconds ⇒ Object
Verification-token lifetime in seconds.
-
#verification_token_required_for_get_account_pii ⇒ Object
Verification token required for get account with PII (email/phone number).
-
#wallet_kit_settings ⇒ Object
Returns the value of attribute wallet_kit_settings.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateAuthProxyConfigIntent
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateAuthProxyConfigIntent
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 123 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TurnkeyClient::UpdateAuthProxyConfigIntent` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TurnkeyClient::UpdateAuthProxyConfigIntent`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'allowed_origins') if (value = attributes[:'allowed_origins']).is_a?(Array) self.allowed_origins = value end end if attributes.key?(:'allowed_auth_methods') if (value = attributes[:'allowed_auth_methods']).is_a?(Array) self.allowed_auth_methods = value end end if attributes.key?(:'send_from_email_address') self.send_from_email_address = attributes[:'send_from_email_address'] end if attributes.key?(:'reply_to_email_address') self.reply_to_email_address = attributes[:'reply_to_email_address'] end if attributes.key?(:'email_auth_template_id') self.email_auth_template_id = attributes[:'email_auth_template_id'] end if attributes.key?(:'otp_template_id') self.otp_template_id = attributes[:'otp_template_id'] end if attributes.key?(:'email_customization_params') self.email_customization_params = attributes[:'email_customization_params'] end if attributes.key?(:'sms_customization_params') self.sms_customization_params = attributes[:'sms_customization_params'] end if attributes.key?(:'wallet_kit_settings') self.wallet_kit_settings = attributes[:'wallet_kit_settings'] end if attributes.key?(:'otp_expiration_seconds') self.otp_expiration_seconds = attributes[:'otp_expiration_seconds'] end if attributes.key?(:'verification_token_expiration_seconds') self.verification_token_expiration_seconds = attributes[:'verification_token_expiration_seconds'] end if attributes.key?(:'session_expiration_seconds') self.session_expiration_seconds = attributes[:'session_expiration_seconds'] end if attributes.key?(:'otp_alphanumeric') self.otp_alphanumeric = attributes[:'otp_alphanumeric'] end if attributes.key?(:'otp_length') self.otp_length = attributes[:'otp_length'] end if attributes.key?(:'send_from_email_sender_name') self.send_from_email_sender_name = attributes[:'send_from_email_sender_name'] end if attributes.key?(:'verification_token_required_for_get_account_pii') self.verification_token_required_for_get_account_pii = attributes[:'verification_token_required_for_get_account_pii'] end end |
Instance Attribute Details
#allowed_auth_methods ⇒ Object
Updated list of allowed proxy authentication methods.
19 20 21 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 19 def allowed_auth_methods @allowed_auth_methods end |
#allowed_origins ⇒ Object
Updated list of allowed origins for CORS.
16 17 18 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 16 def allowed_origins @allowed_origins end |
#email_auth_template_id ⇒ Object
Template ID for email-auth messages.
28 29 30 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 28 def email_auth_template_id @email_auth_template_id end |
#email_customization_params ⇒ Object
Returns the value of attribute email_customization_params.
33 34 35 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 33 def email_customization_params @email_customization_params end |
#otp_alphanumeric ⇒ Object
Enable alphanumeric OTP codes.
49 50 51 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 49 def otp_alphanumeric @otp_alphanumeric end |
#otp_expiration_seconds ⇒ Object
OTP code lifetime in seconds.
40 41 42 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 40 def otp_expiration_seconds @otp_expiration_seconds end |
#otp_length ⇒ Object
Desired OTP code length (6–9).
52 53 54 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 52 def otp_length @otp_length end |
#otp_template_id ⇒ Object
Template ID for OTP SMS messages.
31 32 33 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 31 def otp_template_id @otp_template_id end |
#reply_to_email_address ⇒ Object
Custom reply-to address for auth-related emails.
25 26 27 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 25 def reply_to_email_address @reply_to_email_address end |
#send_from_email_address ⇒ Object
Custom ‘from’ address for auth-related emails.
22 23 24 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 22 def send_from_email_address @send_from_email_address end |
#send_from_email_sender_name ⇒ Object
Custom ‘from’ email sender for auth-related emails.
55 56 57 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 55 def send_from_email_sender_name @send_from_email_sender_name end |
#session_expiration_seconds ⇒ Object
Session lifetime in seconds.
46 47 48 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 46 def session_expiration_seconds @session_expiration_seconds end |
#sms_customization_params ⇒ Object
Returns the value of attribute sms_customization_params.
35 36 37 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 35 def sms_customization_params @sms_customization_params end |
#verification_token_expiration_seconds ⇒ Object
Verification-token lifetime in seconds.
43 44 45 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 43 def verification_token_expiration_seconds @verification_token_expiration_seconds end |
#verification_token_required_for_get_account_pii ⇒ Object
Verification token required for get account with PII (email/phone number). Default false.
58 59 60 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 58 def verification_token_required_for_get_account_pii @verification_token_required_for_get_account_pii end |
#wallet_kit_settings ⇒ Object
Returns the value of attribute wallet_kit_settings.
37 38 39 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 37 def wallet_kit_settings @wallet_kit_settings end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 61 def self.attribute_map { :'allowed_origins' => :'allowedOrigins', :'allowed_auth_methods' => :'allowedAuthMethods', :'send_from_email_address' => :'sendFromEmailAddress', :'reply_to_email_address' => :'replyToEmailAddress', :'email_auth_template_id' => :'emailAuthTemplateId', :'otp_template_id' => :'otpTemplateId', :'email_customization_params' => :'emailCustomizationParams', :'sms_customization_params' => :'smsCustomizationParams', :'wallet_kit_settings' => :'walletKitSettings', :'otp_expiration_seconds' => :'otpExpirationSeconds', :'verification_token_expiration_seconds' => :'verificationTokenExpirationSeconds', :'session_expiration_seconds' => :'sessionExpirationSeconds', :'otp_alphanumeric' => :'otpAlphanumeric', :'otp_length' => :'otpLength', :'send_from_email_sender_name' => :'sendFromEmailSenderName', :'verification_token_required_for_get_account_pii' => :'verificationTokenRequiredForGetAccountPii' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
256 257 258 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 256 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 105 def self.openapi_nullable Set.new([ :'send_from_email_address', :'reply_to_email_address', :'email_auth_template_id', :'otp_template_id', :'otp_expiration_seconds', :'verification_token_expiration_seconds', :'session_expiration_seconds', :'otp_alphanumeric', :'otp_length', :'send_from_email_sender_name', :'verification_token_required_for_get_account_pii' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 83 def self.openapi_types { :'allowed_origins' => :'Object', :'allowed_auth_methods' => :'Object', :'send_from_email_address' => :'Object', :'reply_to_email_address' => :'Object', :'email_auth_template_id' => :'Object', :'otp_template_id' => :'Object', :'email_customization_params' => :'Object', :'sms_customization_params' => :'Object', :'wallet_kit_settings' => :'Object', :'otp_expiration_seconds' => :'Object', :'verification_token_expiration_seconds' => :'Object', :'session_expiration_seconds' => :'Object', :'otp_alphanumeric' => :'Object', :'otp_length' => :'Object', :'send_from_email_sender_name' => :'Object', :'verification_token_required_for_get_account_pii' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 220 def ==(o) return true if self.equal?(o) self.class == o.class && allowed_origins == o.allowed_origins && allowed_auth_methods == o.allowed_auth_methods && send_from_email_address == o.send_from_email_address && reply_to_email_address == o.reply_to_email_address && email_auth_template_id == o.email_auth_template_id && otp_template_id == o.otp_template_id && email_customization_params == o.email_customization_params && sms_customization_params == o.sms_customization_params && wallet_kit_settings == o.wallet_kit_settings && otp_expiration_seconds == o.otp_expiration_seconds && verification_token_expiration_seconds == o.verification_token_expiration_seconds && session_expiration_seconds == o.session_expiration_seconds && otp_alphanumeric == o.otp_alphanumeric && otp_length == o.otp_length && send_from_email_sender_name == o.send_from_email_sender_name && verification_token_required_for_get_account_pii == o.verification_token_required_for_get_account_pii end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 286 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TurnkeyClient.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 355 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 263 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) end end self end |
#eql?(o) ⇒ Boolean
243 244 245 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 243 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
249 250 251 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 249 def hash [allowed_origins, allowed_auth_methods, send_from_email_address, reply_to_email_address, email_auth_template_id, otp_template_id, email_customization_params, sms_customization_params, wallet_kit_settings, otp_expiration_seconds, verification_token_expiration_seconds, session_expiration_seconds, otp_alphanumeric, otp_length, send_from_email_sender_name, verification_token_required_for_get_account_pii].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
207 208 209 210 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 207 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
331 332 333 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 331 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 337 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
325 326 327 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 325 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
214 215 216 |
# File 'lib/turnkey_client/models/update_auth_proxy_config_intent.rb', line 214 def valid? true end |