Class: TurnkeyClient::User

Inherits:
Object
  • Object
show all
Defined in:
lib/turnkey_client/models/user.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ User

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/turnkey_client/models/user.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TurnkeyClient::User` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TurnkeyClient::User`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'user_name')
    self.user_name = attributes[:'user_name']
  end

  if attributes.key?(:'user_email')
    self.user_email = attributes[:'user_email']
  end

  if attributes.key?(:'user_phone_number')
    self.user_phone_number = attributes[:'user_phone_number']
  end

  if attributes.key?(:'authenticators')
    if (value = attributes[:'authenticators']).is_a?(Array)
      self.authenticators = value
    end
  end

  if attributes.key?(:'api_keys')
    if (value = attributes[:'api_keys']).is_a?(Array)
      self.api_keys = value
    end
  end

  if attributes.key?(:'user_tags')
    if (value = attributes[:'user_tags']).is_a?(Array)
      self.user_tags = value
    end
  end

  if attributes.key?(:'oauth_providers')
    if (value = attributes[:'oauth_providers']).is_a?(Array)
      self.oauth_providers = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#api_keysObject

A list of API Key parameters. This field, if not needed, should be an empty array in your request body.



31
32
33
# File 'lib/turnkey_client/models/user.rb', line 31

def api_keys
  @api_keys
end

#authenticatorsObject

A list of Authenticator parameters.



28
29
30
# File 'lib/turnkey_client/models/user.rb', line 28

def authenticators
  @authenticators
end

#created_atObject

Returns the value of attribute created_at.



39
40
41
# File 'lib/turnkey_client/models/user.rb', line 39

def created_at
  @created_at
end

#oauth_providersObject

A list of Oauth Providers.



37
38
39
# File 'lib/turnkey_client/models/user.rb', line 37

def oauth_providers
  @oauth_providers
end

#updated_atObject

Returns the value of attribute updated_at.



41
42
43
# File 'lib/turnkey_client/models/user.rb', line 41

def updated_at
  @updated_at
end

#user_emailObject

The user’s email address.



22
23
24
# File 'lib/turnkey_client/models/user.rb', line 22

def user_email
  @user_email
end

#user_idObject

Unique identifier for a given User.



16
17
18
# File 'lib/turnkey_client/models/user.rb', line 16

def user_id
  @user_id
end

#user_nameObject

Human-readable name for a User.



19
20
21
# File 'lib/turnkey_client/models/user.rb', line 19

def user_name
  @user_name
end

#user_phone_numberObject

The user’s phone number in E.164 format e.g. +13214567890



25
26
27
# File 'lib/turnkey_client/models/user.rb', line 25

def user_phone_number
  @user_phone_number
end

#user_tagsObject

A list of User Tag IDs.



34
35
36
# File 'lib/turnkey_client/models/user.rb', line 34

def user_tags
  @user_tags
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/turnkey_client/models/user.rb', line 44

def self.attribute_map
  {
    :'user_id' => :'userId',
    :'user_name' => :'userName',
    :'user_email' => :'userEmail',
    :'user_phone_number' => :'userPhoneNumber',
    :'authenticators' => :'authenticators',
    :'api_keys' => :'apiKeys',
    :'user_tags' => :'userTags',
    :'oauth_providers' => :'oauthProviders',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



232
233
234
# File 'lib/turnkey_client/models/user.rb', line 232

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
80
81
# File 'lib/turnkey_client/models/user.rb', line 76

def self.openapi_nullable
  Set.new([
    :'user_email',
    :'user_phone_number',
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/turnkey_client/models/user.rb', line 60

def self.openapi_types
  {
    :'user_id' => :'Object',
    :'user_name' => :'Object',
    :'user_email' => :'Object',
    :'user_phone_number' => :'Object',
    :'authenticators' => :'Object',
    :'api_keys' => :'Object',
    :'user_tags' => :'Object',
    :'oauth_providers' => :'Object',
    :'created_at' => :'Object',
    :'updated_at' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/turnkey_client/models/user.rb', line 202

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      user_id == o.user_id &&
      user_name == o.user_name &&
      user_email == o.user_email &&
      user_phone_number == o.user_phone_number &&
      authenticators == o.authenticators &&
      api_keys == o.api_keys &&
      user_tags == o.user_tags &&
      oauth_providers == o.oauth_providers &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/turnkey_client/models/user.rb', line 262

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    TurnkeyClient.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/turnkey_client/models/user.rb', line 331

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/turnkey_client/models/user.rb', line 239

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


219
220
221
# File 'lib/turnkey_client/models/user.rb', line 219

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



225
226
227
# File 'lib/turnkey_client/models/user.rb', line 225

def hash
  [user_id, user_name, user_email, user_phone_number, authenticators, api_keys, user_tags, oauth_providers, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/turnkey_client/models/user.rb', line 149

def list_invalid_properties
  invalid_properties = Array.new
  if @user_id.nil?
    invalid_properties.push('invalid value for "user_id", user_id cannot be nil.')
  end

  if @user_name.nil?
    invalid_properties.push('invalid value for "user_name", user_name cannot be nil.')
  end

  if @authenticators.nil?
    invalid_properties.push('invalid value for "authenticators", authenticators cannot be nil.')
  end

  if @api_keys.nil?
    invalid_properties.push('invalid value for "api_keys", api_keys cannot be nil.')
  end

  if @user_tags.nil?
    invalid_properties.push('invalid value for "user_tags", user_tags cannot be nil.')
  end

  if @oauth_providers.nil?
    invalid_properties.push('invalid value for "oauth_providers", oauth_providers cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



307
308
309
# File 'lib/turnkey_client/models/user.rb', line 307

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/turnkey_client/models/user.rb', line 313

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



301
302
303
# File 'lib/turnkey_client/models/user.rb', line 301

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



188
189
190
191
192
193
194
195
196
197
198
# File 'lib/turnkey_client/models/user.rb', line 188

def valid?
  return false if @user_id.nil?
  return false if @user_name.nil?
  return false if @authenticators.nil?
  return false if @api_keys.nil?
  return false if @user_tags.nil?
  return false if @oauth_providers.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end