Class: TurnkeyClient::UsersApi
- Inherits:
-
Object
- Object
- TurnkeyClient::UsersApi
- Defined in:
- lib/turnkey_client/api/users_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_users(body, opts = {}) ⇒ ActivityResponse
Create users Create users in an existing organization.
-
#create_users_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Create users Create users in an existing organization.
-
#delete_users(body, opts = {}) ⇒ ActivityResponse
Delete users Delete users within an organization.
-
#delete_users_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Delete users Delete users within an organization.
-
#get_user(body, opts = {}) ⇒ GetUserResponse
Get user Get details about a user.
-
#get_user_with_http_info(body, opts = {}) ⇒ Array<(GetUserResponse, Integer, Hash)>
Get user Get details about a user.
-
#get_users(body, opts = {}) ⇒ GetUsersResponse
List users List all users within an organization.
-
#get_users_with_http_info(body, opts = {}) ⇒ Array<(GetUsersResponse, Integer, Hash)>
List users List all users within an organization.
-
#initialize(api_client = ApiClient.default) ⇒ UsersApi
constructor
A new instance of UsersApi.
-
#update_user(body, opts = {}) ⇒ ActivityResponse
Update user Update a user in an existing organization.
-
#update_user_email(body, opts = {}) ⇒ ActivityResponse
Update user’s email Update a user’s email in an existing organization.
-
#update_user_email_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Update user's email Update a user's email in an existing organization.
-
#update_user_name(body, opts = {}) ⇒ ActivityResponse
Update user’s name Update a user’s name in an existing organization.
-
#update_user_name_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Update user's name Update a user's name in an existing organization.
-
#update_user_phone_number(body, opts = {}) ⇒ ActivityResponse
Update user’s phone number Update a user’s phone number in an existing organization.
-
#update_user_phone_number_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Update user's phone number Update a user's phone number in an existing organization.
-
#update_user_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Update user Update a user in an existing organization.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
13 14 15 |
# File 'lib/turnkey_client/api/users_api.rb', line 13 def api_client @api_client end |
Instance Method Details
#create_users(body, opts = {}) ⇒ ActivityResponse
Create users Create users in an existing organization.
23 24 25 26 |
# File 'lib/turnkey_client/api/users_api.rb', line 23 def create_users(body, opts = {}) data, _status_code, _headers = create_users_with_http_info(body, opts) data end |
#create_users_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Create users Create users in an existing organization.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/turnkey_client/api/users_api.rb', line 33 def create_users_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.create_users ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling UsersApi.create_users" end # resource path local_var_path = '/public/v1/submit/create_users' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#create_users\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_users(body, opts = {}) ⇒ ActivityResponse
Delete users Delete users within an organization.
81 82 83 84 |
# File 'lib/turnkey_client/api/users_api.rb', line 81 def delete_users(body, opts = {}) data, _status_code, _headers = delete_users_with_http_info(body, opts) data end |
#delete_users_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Delete users Delete users within an organization.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/turnkey_client/api/users_api.rb', line 91 def delete_users_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.delete_users ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling UsersApi.delete_users" end # resource path local_var_path = '/public/v1/submit/delete_users' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#delete_users\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_user(body, opts = {}) ⇒ GetUserResponse
Get user Get details about a user.
139 140 141 142 |
# File 'lib/turnkey_client/api/users_api.rb', line 139 def get_user(body, opts = {}) data, _status_code, _headers = get_user_with_http_info(body, opts) data end |
#get_user_with_http_info(body, opts = {}) ⇒ Array<(GetUserResponse, Integer, Hash)>
Get user Get details about a user.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/turnkey_client/api/users_api.rb', line 149 def get_user_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.get_user ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling UsersApi.get_user" end # resource path local_var_path = '/public/v1/query/get_user' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'GetUserResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#get_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_users(body, opts = {}) ⇒ GetUsersResponse
List users List all users within an organization.
197 198 199 200 |
# File 'lib/turnkey_client/api/users_api.rb', line 197 def get_users(body, opts = {}) data, _status_code, _headers = get_users_with_http_info(body, opts) data end |
#get_users_with_http_info(body, opts = {}) ⇒ Array<(GetUsersResponse, Integer, Hash)>
List users List all users within an organization.
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/turnkey_client/api/users_api.rb', line 207 def get_users_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.get_users ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling UsersApi.get_users" end # resource path local_var_path = '/public/v1/query/list_users' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'GetUsersResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#get_users\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_user(body, opts = {}) ⇒ ActivityResponse
Update user Update a user in an existing organization.
255 256 257 258 |
# File 'lib/turnkey_client/api/users_api.rb', line 255 def update_user(body, opts = {}) data, _status_code, _headers = update_user_with_http_info(body, opts) data end |
#update_user_email(body, opts = {}) ⇒ ActivityResponse
Update user’s email Update a user’s email in an existing organization.
313 314 315 316 |
# File 'lib/turnkey_client/api/users_api.rb', line 313 def update_user_email(body, opts = {}) data, _status_code, _headers = update_user_email_with_http_info(body, opts) data end |
#update_user_email_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Update user's email Update a user's email in an existing organization.
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/turnkey_client/api/users_api.rb', line 323 def update_user_email_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.update_user_email ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling UsersApi.update_user_email" end # resource path local_var_path = '/public/v1/submit/update_user_email' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#update_user_email\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_user_name(body, opts = {}) ⇒ ActivityResponse
Update user’s name Update a user’s name in an existing organization.
371 372 373 374 |
# File 'lib/turnkey_client/api/users_api.rb', line 371 def update_user_name(body, opts = {}) data, _status_code, _headers = update_user_name_with_http_info(body, opts) data end |
#update_user_name_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Update user's name Update a user's name in an existing organization.
381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/turnkey_client/api/users_api.rb', line 381 def update_user_name_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.update_user_name ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling UsersApi.update_user_name" end # resource path local_var_path = '/public/v1/submit/update_user_name' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#update_user_name\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_user_phone_number(body, opts = {}) ⇒ ActivityResponse
Update user’s phone number Update a user’s phone number in an existing organization.
429 430 431 432 |
# File 'lib/turnkey_client/api/users_api.rb', line 429 def update_user_phone_number(body, opts = {}) data, _status_code, _headers = update_user_phone_number_with_http_info(body, opts) data end |
#update_user_phone_number_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Update user's phone number Update a user's phone number in an existing organization.
439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/turnkey_client/api/users_api.rb', line 439 def update_user_phone_number_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.update_user_phone_number ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling UsersApi.update_user_phone_number" end # resource path local_var_path = '/public/v1/submit/update_user_phone_number' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#update_user_phone_number\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_user_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Update user Update a user in an existing organization.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/turnkey_client/api/users_api.rb', line 265 def update_user_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.update_user ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling UsersApi.update_user" end # resource path local_var_path = '/public/v1/submit/update_user' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#update_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |