Class: TurnkeyClient::WalletAccount

Inherits:
Object
  • Object
show all
Defined in:
lib/turnkey_client/models/wallet_account.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WalletAccount

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/turnkey_client/models/wallet_account.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TurnkeyClient::WalletAccount` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TurnkeyClient::WalletAccount`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'wallet_account_id')
    self. = attributes[:'wallet_account_id']
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  end

  if attributes.key?(:'wallet_id')
    self.wallet_id = attributes[:'wallet_id']
  end

  if attributes.key?(:'curve')
    self.curve = attributes[:'curve']
  end

  if attributes.key?(:'path_format')
    self.path_format = attributes[:'path_format']
  end

  if attributes.key?(:'path')
    self.path = attributes[:'path']
  end

  if attributes.key?(:'address_format')
    self.address_format = attributes[:'address_format']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'public_key')
    self.public_key = attributes[:'public_key']
  end

  if attributes.key?(:'wallet_details')
    self.wallet_details = attributes[:'wallet_details']
  end
end

Instance Attribute Details

#addressObject

Address generated using the Wallet seed and Account parameters.



34
35
36
# File 'lib/turnkey_client/models/wallet_account.rb', line 34

def address
  @address
end

#address_formatObject

Returns the value of attribute address_format.



31
32
33
# File 'lib/turnkey_client/models/wallet_account.rb', line 31

def address_format
  @address_format
end

#created_atObject

Returns the value of attribute created_at.



36
37
38
# File 'lib/turnkey_client/models/wallet_account.rb', line 36

def created_at
  @created_at
end

#curveObject

Returns the value of attribute curve.



24
25
26
# File 'lib/turnkey_client/models/wallet_account.rb', line 24

def curve
  @curve
end

#organization_idObject

The Organization the Account belongs to.



19
20
21
# File 'lib/turnkey_client/models/wallet_account.rb', line 19

def organization_id
  @organization_id
end

#pathObject

Path used to generate the Account.



29
30
31
# File 'lib/turnkey_client/models/wallet_account.rb', line 29

def path
  @path
end

#path_formatObject

Returns the value of attribute path_format.



26
27
28
# File 'lib/turnkey_client/models/wallet_account.rb', line 26

def path_format
  @path_format
end

#public_keyObject

The public component of this wallet account’s underlying cryptographic key pair.



41
42
43
# File 'lib/turnkey_client/models/wallet_account.rb', line 41

def public_key
  @public_key
end

#updated_atObject

Returns the value of attribute updated_at.



38
39
40
# File 'lib/turnkey_client/models/wallet_account.rb', line 38

def updated_at
  @updated_at
end

#wallet_account_idObject

Unique identifier for a given Wallet Account.



16
17
18
# File 'lib/turnkey_client/models/wallet_account.rb', line 16

def 
  @wallet_account_id
end

#wallet_detailsObject

Returns the value of attribute wallet_details.



43
44
45
# File 'lib/turnkey_client/models/wallet_account.rb', line 43

def wallet_details
  @wallet_details
end

#wallet_idObject

The Wallet the Account was derived from.



22
23
24
# File 'lib/turnkey_client/models/wallet_account.rb', line 22

def wallet_id
  @wallet_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/turnkey_client/models/wallet_account.rb', line 46

def self.attribute_map
  {
    :'wallet_account_id' => :'walletAccountId',
    :'organization_id' => :'organizationId',
    :'wallet_id' => :'walletId',
    :'curve' => :'curve',
    :'path_format' => :'pathFormat',
    :'path' => :'path',
    :'address_format' => :'addressFormat',
    :'address' => :'address',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt',
    :'public_key' => :'publicKey',
    :'wallet_details' => :'walletDetails'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



249
250
251
# File 'lib/turnkey_client/models/wallet_account.rb', line 249

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
86
# File 'lib/turnkey_client/models/wallet_account.rb', line 82

def self.openapi_nullable
  Set.new([
    :'public_key',
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/turnkey_client/models/wallet_account.rb', line 64

def self.openapi_types
  {
    :'wallet_account_id' => :'Object',
    :'organization_id' => :'Object',
    :'wallet_id' => :'Object',
    :'curve' => :'Object',
    :'path_format' => :'Object',
    :'path' => :'Object',
    :'address_format' => :'Object',
    :'address' => :'Object',
    :'created_at' => :'Object',
    :'updated_at' => :'Object',
    :'public_key' => :'Object',
    :'wallet_details' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/turnkey_client/models/wallet_account.rb', line 217

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      organization_id == o.organization_id &&
      wallet_id == o.wallet_id &&
      curve == o.curve &&
      path_format == o.path_format &&
      path == o.path &&
      address_format == o.address_format &&
      address == o.address &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      public_key == o.public_key &&
      wallet_details == o.wallet_details
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/turnkey_client/models/wallet_account.rb', line 279

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    TurnkeyClient.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/turnkey_client/models/wallet_account.rb', line 348

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/turnkey_client/models/wallet_account.rb', line 256

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


236
237
238
# File 'lib/turnkey_client/models/wallet_account.rb', line 236

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



242
243
244
# File 'lib/turnkey_client/models/wallet_account.rb', line 242

def hash
  [, organization_id, wallet_id, curve, path_format, path, address_format, address, created_at, updated_at, public_key, wallet_details].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/turnkey_client/models/wallet_account.rb', line 154

def list_invalid_properties
  invalid_properties = Array.new
  if @wallet_account_id.nil?
    invalid_properties.push('invalid value for "wallet_account_id", wallet_account_id cannot be nil.')
  end

  if @organization_id.nil?
    invalid_properties.push('invalid value for "organization_id", organization_id cannot be nil.')
  end

  if @wallet_id.nil?
    invalid_properties.push('invalid value for "wallet_id", wallet_id cannot be nil.')
  end

  if @curve.nil?
    invalid_properties.push('invalid value for "curve", curve cannot be nil.')
  end

  if @path_format.nil?
    invalid_properties.push('invalid value for "path_format", path_format cannot be nil.')
  end

  if @path.nil?
    invalid_properties.push('invalid value for "path", path cannot be nil.')
  end

  if @address_format.nil?
    invalid_properties.push('invalid value for "address_format", address_format cannot be nil.')
  end

  if @address.nil?
    invalid_properties.push('invalid value for "address", address cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



324
325
326
# File 'lib/turnkey_client/models/wallet_account.rb', line 324

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/turnkey_client/models/wallet_account.rb', line 330

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



318
319
320
# File 'lib/turnkey_client/models/wallet_account.rb', line 318

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/turnkey_client/models/wallet_account.rb', line 201

def valid?
  return false if @wallet_account_id.nil?
  return false if @organization_id.nil?
  return false if @wallet_id.nil?
  return false if @curve.nil?
  return false if @path_format.nil?
  return false if @path.nil?
  return false if @address_format.nil?
  return false if @address.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end