Class: TurnkeyClient::WalletsApi
- Inherits:
-
Object
- Object
- TurnkeyClient::WalletsApi
- Defined in:
- lib/turnkey_client/api/wallets_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_wallet(body, opts = {}) ⇒ ActivityResponse
Create wallet Create a wallet and derive addresses.
-
#create_wallet_accounts(body, opts = {}) ⇒ ActivityResponse
Create wallet accounts Derive additional addresses using an existing wallet.
-
#create_wallet_accounts_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Create wallet accounts Derive additional addresses using an existing wallet.
-
#create_wallet_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Create wallet Create a wallet and derive addresses.
-
#delete_wallet_accounts(body, opts = {}) ⇒ ActivityResponse
Delete wallet accounts Delete wallet accounts for an organization.
-
#delete_wallet_accounts_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Delete wallet accounts Delete wallet accounts for an organization.
-
#delete_wallets(body, opts = {}) ⇒ ActivityResponse
Delete wallets Delete wallets for an organization.
-
#delete_wallets_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Delete wallets Delete wallets for an organization.
-
#export_wallet(body, opts = {}) ⇒ ActivityResponse
Export wallet Export a wallet.
-
#export_wallet_account(body, opts = {}) ⇒ ActivityResponse
Export wallet account Export a wallet account.
-
#export_wallet_account_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Export wallet account Export a wallet account.
-
#export_wallet_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Export wallet Export a wallet.
-
#get_wallet(body, opts = {}) ⇒ GetWalletResponse
Get wallet Get details about a wallet.
-
#get_wallet_account(body, opts = {}) ⇒ GetWalletAccountResponse
Get wallet account Get a single wallet account.
-
#get_wallet_account_with_http_info(body, opts = {}) ⇒ Array<(GetWalletAccountResponse, Integer, Hash)>
Get wallet account Get a single wallet account.
-
#get_wallet_accounts(body, opts = {}) ⇒ GetWalletAccountsResponse
List wallets accounts List all accounts within a wallet.
-
#get_wallet_accounts_with_http_info(body, opts = {}) ⇒ Array<(GetWalletAccountsResponse, Integer, Hash)>
List wallets accounts List all accounts within a wallet.
-
#get_wallet_with_http_info(body, opts = {}) ⇒ Array<(GetWalletResponse, Integer, Hash)>
Get wallet Get details about a wallet.
-
#get_wallets(body, opts = {}) ⇒ GetWalletsResponse
List wallets List all wallets within an organization.
-
#get_wallets_with_http_info(body, opts = {}) ⇒ Array<(GetWalletsResponse, Integer, Hash)>
List wallets List all wallets within an organization.
-
#import_wallet(body, opts = {}) ⇒ ActivityResponse
Import wallet Import a wallet.
-
#import_wallet_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Import wallet Import a wallet.
-
#init_import_wallet(body, opts = {}) ⇒ ActivityResponse
Init import wallet Initialize a new wallet import.
-
#init_import_wallet_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Init import wallet Initialize a new wallet import.
-
#initialize(api_client = ApiClient.default) ⇒ WalletsApi
constructor
A new instance of WalletsApi.
-
#update_wallet(body, opts = {}) ⇒ ActivityResponse
Update wallet Update a wallet for an organization.
-
#update_wallet_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Update wallet Update a wallet for an organization.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ WalletsApi
Returns a new instance of WalletsApi.
15 16 17 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 15 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
13 14 15 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 13 def api_client @api_client end |
Instance Method Details
#create_wallet(body, opts = {}) ⇒ ActivityResponse
Create wallet Create a wallet and derive addresses.
23 24 25 26 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 23 def create_wallet(body, opts = {}) data, _status_code, _headers = create_wallet_with_http_info(body, opts) data end |
#create_wallet_accounts(body, opts = {}) ⇒ ActivityResponse
Create wallet accounts Derive additional addresses using an existing wallet.
81 82 83 84 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 81 def create_wallet_accounts(body, opts = {}) data, _status_code, _headers = create_wallet_accounts_with_http_info(body, opts) data end |
#create_wallet_accounts_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Create wallet accounts Derive additional addresses using an existing wallet.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 91 def create_wallet_accounts_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalletsApi.create_wallet_accounts ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling WalletsApi.create_wallet_accounts" end # resource path local_var_path = '/public/v1/submit/create_wallet_accounts' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalletsApi#create_wallet_accounts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_wallet_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Create wallet Create a wallet and derive addresses.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 33 def create_wallet_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalletsApi.create_wallet ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling WalletsApi.create_wallet" end # resource path local_var_path = '/public/v1/submit/create_wallet' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalletsApi#create_wallet\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_wallet_accounts(body, opts = {}) ⇒ ActivityResponse
Delete wallet accounts Delete wallet accounts for an organization.
139 140 141 142 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 139 def delete_wallet_accounts(body, opts = {}) data, _status_code, _headers = delete_wallet_accounts_with_http_info(body, opts) data end |
#delete_wallet_accounts_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Delete wallet accounts Delete wallet accounts for an organization.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 149 def delete_wallet_accounts_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalletsApi.delete_wallet_accounts ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling WalletsApi.delete_wallet_accounts" end # resource path local_var_path = '/public/v1/submit/delete_wallet_accounts' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalletsApi#delete_wallet_accounts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_wallets(body, opts = {}) ⇒ ActivityResponse
Delete wallets Delete wallets for an organization.
197 198 199 200 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 197 def delete_wallets(body, opts = {}) data, _status_code, _headers = delete_wallets_with_http_info(body, opts) data end |
#delete_wallets_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Delete wallets Delete wallets for an organization.
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 207 def delete_wallets_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalletsApi.delete_wallets ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling WalletsApi.delete_wallets" end # resource path local_var_path = '/public/v1/submit/delete_wallets' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalletsApi#delete_wallets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#export_wallet(body, opts = {}) ⇒ ActivityResponse
Export wallet Export a wallet.
255 256 257 258 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 255 def export_wallet(body, opts = {}) data, _status_code, _headers = export_wallet_with_http_info(body, opts) data end |
#export_wallet_account(body, opts = {}) ⇒ ActivityResponse
Export wallet account Export a wallet account.
313 314 315 316 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 313 def export_wallet_account(body, opts = {}) data, _status_code, _headers = export_wallet_account_with_http_info(body, opts) data end |
#export_wallet_account_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Export wallet account Export a wallet account.
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 323 def export_wallet_account_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalletsApi.export_wallet_account ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling WalletsApi.export_wallet_account" end # resource path local_var_path = '/public/v1/submit/export_wallet_account' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalletsApi#export_wallet_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#export_wallet_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Export wallet Export a wallet.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 265 def export_wallet_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalletsApi.export_wallet ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling WalletsApi.export_wallet" end # resource path local_var_path = '/public/v1/submit/export_wallet' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalletsApi#export_wallet\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_wallet(body, opts = {}) ⇒ GetWalletResponse
Get wallet Get details about a wallet.
371 372 373 374 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 371 def get_wallet(body, opts = {}) data, _status_code, _headers = get_wallet_with_http_info(body, opts) data end |
#get_wallet_account(body, opts = {}) ⇒ GetWalletAccountResponse
Get wallet account Get a single wallet account.
429 430 431 432 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 429 def get_wallet_account(body, opts = {}) data, _status_code, _headers = get_wallet_account_with_http_info(body, opts) data end |
#get_wallet_account_with_http_info(body, opts = {}) ⇒ Array<(GetWalletAccountResponse, Integer, Hash)>
Get wallet account Get a single wallet account.
439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 439 def get_wallet_account_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalletsApi.get_wallet_account ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling WalletsApi.get_wallet_account" end # resource path local_var_path = '/public/v1/query/get_wallet_account' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'GetWalletAccountResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalletsApi#get_wallet_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_wallet_accounts(body, opts = {}) ⇒ GetWalletAccountsResponse
List wallets accounts List all accounts within a wallet.
487 488 489 490 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 487 def get_wallet_accounts(body, opts = {}) data, _status_code, _headers = get_wallet_accounts_with_http_info(body, opts) data end |
#get_wallet_accounts_with_http_info(body, opts = {}) ⇒ Array<(GetWalletAccountsResponse, Integer, Hash)>
List wallets accounts List all accounts within a wallet.
497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 497 def get_wallet_accounts_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalletsApi.get_wallet_accounts ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling WalletsApi.get_wallet_accounts" end # resource path local_var_path = '/public/v1/query/list_wallet_accounts' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'GetWalletAccountsResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalletsApi#get_wallet_accounts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_wallet_with_http_info(body, opts = {}) ⇒ Array<(GetWalletResponse, Integer, Hash)>
Get wallet Get details about a wallet.
381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 381 def get_wallet_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalletsApi.get_wallet ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling WalletsApi.get_wallet" end # resource path local_var_path = '/public/v1/query/get_wallet' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'GetWalletResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalletsApi#get_wallet\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_wallets(body, opts = {}) ⇒ GetWalletsResponse
List wallets List all wallets within an organization.
545 546 547 548 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 545 def get_wallets(body, opts = {}) data, _status_code, _headers = get_wallets_with_http_info(body, opts) data end |
#get_wallets_with_http_info(body, opts = {}) ⇒ Array<(GetWalletsResponse, Integer, Hash)>
List wallets List all wallets within an organization.
555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 555 def get_wallets_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalletsApi.get_wallets ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling WalletsApi.get_wallets" end # resource path local_var_path = '/public/v1/query/list_wallets' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'GetWalletsResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalletsApi#get_wallets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#import_wallet(body, opts = {}) ⇒ ActivityResponse
Import wallet Import a wallet.
603 604 605 606 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 603 def import_wallet(body, opts = {}) data, _status_code, _headers = import_wallet_with_http_info(body, opts) data end |
#import_wallet_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Import wallet Import a wallet.
613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 613 def import_wallet_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalletsApi.import_wallet ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling WalletsApi.import_wallet" end # resource path local_var_path = '/public/v1/submit/import_wallet' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalletsApi#import_wallet\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#init_import_wallet(body, opts = {}) ⇒ ActivityResponse
Init import wallet Initialize a new wallet import.
661 662 663 664 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 661 def init_import_wallet(body, opts = {}) data, _status_code, _headers = init_import_wallet_with_http_info(body, opts) data end |
#init_import_wallet_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Init import wallet Initialize a new wallet import.
671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 671 def init_import_wallet_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalletsApi.init_import_wallet ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling WalletsApi.init_import_wallet" end # resource path local_var_path = '/public/v1/submit/init_import_wallet' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalletsApi#init_import_wallet\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_wallet(body, opts = {}) ⇒ ActivityResponse
Update wallet Update a wallet for an organization.
719 720 721 722 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 719 def update_wallet(body, opts = {}) data, _status_code, _headers = update_wallet_with_http_info(body, opts) data end |
#update_wallet_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Update wallet Update a wallet for an organization.
729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 |
# File 'lib/turnkey_client/api/wallets_api.rb', line 729 def update_wallet_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalletsApi.update_wallet ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling WalletsApi.update_wallet" end # resource path local_var_path = '/public/v1/submit/update_wallet' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalletsApi#update_wallet\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |