Class: TurnkeyClient::EthSendTransactionIntent
- Inherits:
-
Object
- Object
- TurnkeyClient::EthSendTransactionIntent
- Defined in:
- lib/turnkey_client/models/eth_send_transaction_intent.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#caip2 ⇒ Object
CAIP-2 chain ID (e.g., ‘eip155:1’ for Ethereum mainnet).
-
#data ⇒ Object
Hex-encoded call data for contract interactions.
-
#deadline ⇒ Object
Unix timestamp in seconds for EIP-712 execution deadline.
-
#from ⇒ Object
A wallet or private key address to sign with.
-
#gas_limit ⇒ Object
Maximum amount of gas to use for this transaction, for EIP-1559 transactions.
-
#gas_station_nonce ⇒ Object
The gas station delegate contract nonce.
-
#max_fee_per_gas ⇒ Object
Maximum total fee per gas unit (base fee + priority fee) in wei.
-
#max_priority_fee_per_gas ⇒ Object
Maximum priority fee (tip) per gas unit in wei.
-
#nonce ⇒ Object
Transaction nonce, for EIP-1559 and Turnkey Gas Station authorizations.
-
#sponsor ⇒ Object
Whether to sponsor this transaction via Gas Station.
-
#to ⇒ Object
Recipient address as a hex string with 0x prefix.
-
#value ⇒ Object
Amount of native asset to send in wei.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EthSendTransactionIntent
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ EthSendTransactionIntent
Initializes the object
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 126 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TurnkeyClient::EthSendTransactionIntent` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TurnkeyClient::EthSendTransactionIntent`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'from') self.from = attributes[:'from'] end if attributes.key?(:'sponsor') self.sponsor = attributes[:'sponsor'] end if attributes.key?(:'caip2') self.caip2 = attributes[:'caip2'] end if attributes.key?(:'to') self.to = attributes[:'to'] end if attributes.key?(:'value') self.value = attributes[:'value'] end if attributes.key?(:'data') self.data = attributes[:'data'] end if attributes.key?(:'nonce') self.nonce = attributes[:'nonce'] end if attributes.key?(:'gas_limit') self.gas_limit = attributes[:'gas_limit'] end if attributes.key?(:'max_fee_per_gas') self.max_fee_per_gas = attributes[:'max_fee_per_gas'] end if attributes.key?(:'max_priority_fee_per_gas') self.max_priority_fee_per_gas = attributes[:'max_priority_fee_per_gas'] end if attributes.key?(:'deadline') self.deadline = attributes[:'deadline'] end if attributes.key?(:'gas_station_nonce') self.gas_station_nonce = attributes[:'gas_station_nonce'] end end |
Instance Attribute Details
#caip2 ⇒ Object
CAIP-2 chain ID (e.g., ‘eip155:1’ for Ethereum mainnet).
22 23 24 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 22 def caip2 @caip2 end |
#data ⇒ Object
Hex-encoded call data for contract interactions.
31 32 33 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 31 def data @data end |
#deadline ⇒ Object
Unix timestamp in seconds for EIP-712 execution deadline. Only used when sponsor=true.
46 47 48 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 46 def deadline @deadline end |
#from ⇒ Object
A wallet or private key address to sign with. This does not support private key IDs.
16 17 18 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 16 def from @from end |
#gas_limit ⇒ Object
Maximum amount of gas to use for this transaction, for EIP-1559 transactions.
37 38 39 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 37 def gas_limit @gas_limit end |
#gas_station_nonce ⇒ Object
The gas station delegate contract nonce. Only used when sponsor=true. Include this if you want maximal security posture.
49 50 51 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 49 def gas_station_nonce @gas_station_nonce end |
#max_fee_per_gas ⇒ Object
Maximum total fee per gas unit (base fee + priority fee) in wei. Required for non-sponsored (EIP-1559) transactions. Not used for sponsored transactions.
40 41 42 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 40 def max_fee_per_gas @max_fee_per_gas end |
#max_priority_fee_per_gas ⇒ Object
Maximum priority fee (tip) per gas unit in wei. Required for non-sponsored (EIP-1559) transactions. Not used for sponsored transactions.
43 44 45 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 43 def max_priority_fee_per_gas @max_priority_fee_per_gas end |
#nonce ⇒ Object
Transaction nonce, for EIP-1559 and Turnkey Gas Station authorizations.
34 35 36 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 34 def nonce @nonce end |
#sponsor ⇒ Object
Whether to sponsor this transaction via Gas Station.
19 20 21 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 19 def sponsor @sponsor end |
#to ⇒ Object
Recipient address as a hex string with 0x prefix.
25 26 27 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 25 def to @to end |
#value ⇒ Object
Amount of native asset to send in wei.
28 29 30 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 28 def value @value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 74 def self.attribute_map { :'from' => :'from', :'sponsor' => :'sponsor', :'caip2' => :'caip2', :'to' => :'to', :'value' => :'value', :'data' => :'data', :'nonce' => :'nonce', :'gas_limit' => :'gasLimit', :'max_fee_per_gas' => :'maxFeePerGas', :'max_priority_fee_per_gas' => :'maxPriorityFeePerGas', :'deadline' => :'deadline', :'gas_station_nonce' => :'gasStationNonce' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
262 263 264 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 262 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 110 def self.openapi_nullable Set.new([ :'sponsor', :'value', :'data', :'nonce', :'gas_limit', :'max_fee_per_gas', :'max_priority_fee_per_gas', :'deadline', :'gas_station_nonce' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 92 def self.openapi_types { :'from' => :'Object', :'sponsor' => :'Object', :'caip2' => :'Object', :'to' => :'Object', :'value' => :'Object', :'data' => :'Object', :'nonce' => :'Object', :'gas_limit' => :'Object', :'max_fee_per_gas' => :'Object', :'max_priority_fee_per_gas' => :'Object', :'deadline' => :'Object', :'gas_station_nonce' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 230 def ==(o) return true if self.equal?(o) self.class == o.class && from == o.from && sponsor == o.sponsor && caip2 == o.caip2 && to == o.to && value == o.value && data == o.data && nonce == o.nonce && gas_limit == o.gas_limit && max_fee_per_gas == o.max_fee_per_gas && max_priority_fee_per_gas == o.max_priority_fee_per_gas && deadline == o.deadline && gas_station_nonce == o.gas_station_nonce end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 292 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TurnkeyClient.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 361 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 269 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) end end self end |
#eql?(o) ⇒ Boolean
249 250 251 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 249 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
255 256 257 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 255 def hash [from, sponsor, caip2, to, value, data, nonce, gas_limit, max_fee_per_gas, max_priority_fee_per_gas, deadline, gas_station_nonce].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 190 def list_invalid_properties invalid_properties = Array.new if @from.nil? invalid_properties.push('invalid value for "from", from cannot be nil.') end if @caip2.nil? invalid_properties.push('invalid value for "caip2", caip2 cannot be nil.') end if @to.nil? invalid_properties.push('invalid value for "to", to cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
337 338 339 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 337 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 343 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
331 332 333 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 331 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
209 210 211 212 213 214 215 216 |
# File 'lib/turnkey_client/models/eth_send_transaction_intent.rb', line 209 def valid? return false if @from.nil? return false if @caip2.nil? caip2_validator = EnumAttributeValidator.new('Object', ['eip155:1', 'eip155:11155111', 'eip155:8453', 'eip155:84532', 'eip155:137', 'eip155:80002']) return false unless caip2_validator.valid?(@caip2) return false if @to.nil? true end |