Class: TurnkeyClient::InitFiatOnRampIntent
- Inherits:
-
Object
- Object
- TurnkeyClient::InitFiatOnRampIntent
- Defined in:
- lib/turnkey_client/models/init_fiat_on_ramp_intent.rb
Instance Attribute Summary collapse
-
#country_code ⇒ Object
ISO 3166-1 two-digit country code for Coinbase representing the purchasing user’s country of residence, e.g., US, GB.
-
#country_subdivision_code ⇒ Object
ISO 3166-2 two-digit country subdivision code for Coinbase representing the purchasing user’s subdivision of residence within their country, e.g.
-
#crypto_currency_code ⇒ Object
Returns the value of attribute crypto_currency_code.
-
#fiat_currency_amount ⇒ Object
Specifies a preset fiat amount for the transaction, e.g., ‘100’.
-
#fiat_currency_code ⇒ Object
Returns the value of attribute fiat_currency_code.
-
#network ⇒ Object
Returns the value of attribute network.
-
#onramp_provider ⇒ Object
Returns the value of attribute onramp_provider.
-
#payment_method ⇒ Object
Returns the value of attribute payment_method.
-
#sandbox_mode ⇒ Object
Optional flag to indicate whether to use the sandbox mode to simulate transactions for the on-ramp provider.
-
#url_for_signature ⇒ Object
Optional MoonPay Widget URL to sign when using MoonPay client SDKs with URL Signing enabled.
-
#wallet_address ⇒ Object
Destination wallet address for the buy transaction.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InitFiatOnRampIntent
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ InitFiatOnRampIntent
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TurnkeyClient::InitFiatOnRampIntent` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TurnkeyClient::InitFiatOnRampIntent`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'onramp_provider') self.onramp_provider = attributes[:'onramp_provider'] end if attributes.key?(:'wallet_address') self.wallet_address = attributes[:'wallet_address'] end if attributes.key?(:'network') self.network = attributes[:'network'] end if attributes.key?(:'crypto_currency_code') self.crypto_currency_code = attributes[:'crypto_currency_code'] end if attributes.key?(:'fiat_currency_code') self.fiat_currency_code = attributes[:'fiat_currency_code'] end if attributes.key?(:'fiat_currency_amount') self.fiat_currency_amount = attributes[:'fiat_currency_amount'] end if attributes.key?(:'payment_method') self.payment_method = attributes[:'payment_method'] end if attributes.key?(:'country_code') self.country_code = attributes[:'country_code'] end if attributes.key?(:'country_subdivision_code') self.country_subdivision_code = attributes[:'country_subdivision_code'] end if attributes.key?(:'sandbox_mode') self.sandbox_mode = attributes[:'sandbox_mode'] end if attributes.key?(:'url_for_signature') self.url_for_signature = attributes[:'url_for_signature'] end end |
Instance Attribute Details
#country_code ⇒ Object
ISO 3166-1 two-digit country code for Coinbase representing the purchasing user’s country of residence, e.g., US, GB.
32 33 34 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 32 def country_code @country_code end |
#country_subdivision_code ⇒ Object
ISO 3166-2 two-digit country subdivision code for Coinbase representing the purchasing user’s subdivision of residence within their country, e.g. NY. Required if country_code=US.
35 36 37 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 35 def country_subdivision_code @country_subdivision_code end |
#crypto_currency_code ⇒ Object
Returns the value of attribute crypto_currency_code.
22 23 24 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 22 def crypto_currency_code @crypto_currency_code end |
#fiat_currency_amount ⇒ Object
Specifies a preset fiat amount for the transaction, e.g., ‘100’. Must be greater than ‘20’. If not provided, the user will be prompted to enter an amount.
27 28 29 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 27 def fiat_currency_amount @fiat_currency_amount end |
#fiat_currency_code ⇒ Object
Returns the value of attribute fiat_currency_code.
24 25 26 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 24 def fiat_currency_code @fiat_currency_code end |
#network ⇒ Object
Returns the value of attribute network.
20 21 22 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 20 def network @network end |
#onramp_provider ⇒ Object
Returns the value of attribute onramp_provider.
15 16 17 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 15 def onramp_provider @onramp_provider end |
#payment_method ⇒ Object
Returns the value of attribute payment_method.
29 30 31 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 29 def payment_method @payment_method end |
#sandbox_mode ⇒ Object
Optional flag to indicate whether to use the sandbox mode to simulate transactions for the on-ramp provider. Default is false.
38 39 40 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 38 def sandbox_mode @sandbox_mode end |
#url_for_signature ⇒ Object
Optional MoonPay Widget URL to sign when using MoonPay client SDKs with URL Signing enabled.
41 42 43 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 41 def url_for_signature @url_for_signature end |
#wallet_address ⇒ Object
Destination wallet address for the buy transaction.
18 19 20 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 18 def wallet_address @wallet_address end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 44 def self.attribute_map { :'onramp_provider' => :'onrampProvider', :'wallet_address' => :'walletAddress', :'network' => :'network', :'crypto_currency_code' => :'cryptoCurrencyCode', :'fiat_currency_code' => :'fiatCurrencyCode', :'fiat_currency_amount' => :'fiatCurrencyAmount', :'payment_method' => :'paymentMethod', :'country_code' => :'countryCode', :'country_subdivision_code' => :'countrySubdivisionCode', :'sandbox_mode' => :'sandboxMode', :'url_for_signature' => :'urlForSignature' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 214 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 82 83 84 85 86 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 78 def self.openapi_nullable Set.new([ :'fiat_currency_amount', :'country_code', :'country_subdivision_code', :'sandbox_mode', :'url_for_signature' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 61 def self.openapi_types { :'onramp_provider' => :'Object', :'wallet_address' => :'Object', :'network' => :'Object', :'crypto_currency_code' => :'Object', :'fiat_currency_code' => :'Object', :'fiat_currency_amount' => :'Object', :'payment_method' => :'Object', :'country_code' => :'Object', :'country_subdivision_code' => :'Object', :'sandbox_mode' => :'Object', :'url_for_signature' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 183 def ==(o) return true if self.equal?(o) self.class == o.class && onramp_provider == o.onramp_provider && wallet_address == o.wallet_address && network == o.network && crypto_currency_code == o.crypto_currency_code && fiat_currency_code == o.fiat_currency_code && fiat_currency_amount == o.fiat_currency_amount && payment_method == o.payment_method && country_code == o.country_code && country_subdivision_code == o.country_subdivision_code && sandbox_mode == o.sandbox_mode && url_for_signature == o.url_for_signature end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 244 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TurnkeyClient.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 313 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 221 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) end end self end |
#eql?(o) ⇒ Boolean
201 202 203 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 201 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
207 208 209 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 207 def hash [onramp_provider, wallet_address, network, crypto_currency_code, fiat_currency_code, fiat_currency_amount, payment_method, country_code, country_subdivision_code, sandbox_mode, url_for_signature].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 150 def list_invalid_properties invalid_properties = Array.new if @onramp_provider.nil? invalid_properties.push('invalid value for "onramp_provider", onramp_provider cannot be nil.') end if @wallet_address.nil? invalid_properties.push('invalid value for "wallet_address", wallet_address cannot be nil.') end if @network.nil? invalid_properties.push('invalid value for "network", network cannot be nil.') end if @crypto_currency_code.nil? invalid_properties.push('invalid value for "crypto_currency_code", crypto_currency_code cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
289 290 291 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 289 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 295 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
283 284 285 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 283 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
173 174 175 176 177 178 179 |
# File 'lib/turnkey_client/models/init_fiat_on_ramp_intent.rb', line 173 def valid? return false if @onramp_provider.nil? return false if @wallet_address.nil? return false if @network.nil? return false if @crypto_currency_code.nil? true end |