Class: TurnkeyClient::InitOtpIntent
- Inherits:
-
Object
- Object
- TurnkeyClient::InitOtpIntent
- Defined in:
- lib/turnkey_client/models/init_otp_intent.rb
Instance Attribute Summary collapse
-
#alphanumeric ⇒ Object
Optional flag to specify if the OTP code should be alphanumeric (Crockford’s Base32).
-
#contact ⇒ Object
Email or phone number to send the OTP code to.
-
#email_customization ⇒ Object
Returns the value of attribute email_customization.
-
#expiration_seconds ⇒ Object
Expiration window (in seconds) indicating how long the OTP is valid for.
-
#otp_length ⇒ Object
Optional length of the OTP code.
-
#otp_type ⇒ Object
Whether to send OTP via SMS or email.
-
#reply_to_email_address ⇒ Object
Optional custom email address to use as reply-to.
-
#send_from_email_address ⇒ Object
Optional custom email address from which to send the OTP email.
-
#send_from_email_sender_name ⇒ Object
Optional custom sender name for use with sendFromEmailAddress; if left empty, will default to ‘Notifications’.
-
#sms_customization ⇒ Object
Returns the value of attribute sms_customization.
-
#user_identifier ⇒ Object
Optional client-generated user identifier to enable per-user rate limiting for SMS auth.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InitOtpIntent
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ InitOtpIntent
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TurnkeyClient::InitOtpIntent` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TurnkeyClient::InitOtpIntent`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'otp_type') self.otp_type = attributes[:'otp_type'] end if attributes.key?(:'contact') self.contact = attributes[:'contact'] end if attributes.key?(:'otp_length') self.otp_length = attributes[:'otp_length'] end if attributes.key?(:'email_customization') self.email_customization = attributes[:'email_customization'] end if attributes.key?(:'sms_customization') self.sms_customization = attributes[:'sms_customization'] end if attributes.key?(:'user_identifier') self.user_identifier = attributes[:'user_identifier'] end if attributes.key?(:'send_from_email_address') self.send_from_email_address = attributes[:'send_from_email_address'] end if attributes.key?(:'alphanumeric') self.alphanumeric = attributes[:'alphanumeric'] end if attributes.key?(:'send_from_email_sender_name') self.send_from_email_sender_name = attributes[:'send_from_email_sender_name'] end if attributes.key?(:'expiration_seconds') self.expiration_seconds = attributes[:'expiration_seconds'] end if attributes.key?(:'reply_to_email_address') self.reply_to_email_address = attributes[:'reply_to_email_address'] end end |
Instance Attribute Details
#alphanumeric ⇒ Object
Optional flag to specify if the OTP code should be alphanumeric (Crockford’s Base32). Default = true
35 36 37 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 35 def alphanumeric @alphanumeric end |
#contact ⇒ Object
Email or phone number to send the OTP code to
19 20 21 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 19 def contact @contact end |
#email_customization ⇒ Object
Returns the value of attribute email_customization.
24 25 26 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 24 def email_customization @email_customization end |
#expiration_seconds ⇒ Object
Expiration window (in seconds) indicating how long the OTP is valid for. If not provided, a default of 5 minutes will be used. Maximum value is 600 seconds (10 minutes)
41 42 43 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 41 def expiration_seconds @expiration_seconds end |
#otp_length ⇒ Object
Optional length of the OTP code. Default = 9
22 23 24 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 22 def otp_length @otp_length end |
#otp_type ⇒ Object
Whether to send OTP via SMS or email. Possible values: OTP_TYPE_SMS, OTP_TYPE_EMAIL
16 17 18 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 16 def otp_type @otp_type end |
#reply_to_email_address ⇒ Object
Optional custom email address to use as reply-to
44 45 46 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 44 def reply_to_email_address @reply_to_email_address end |
#send_from_email_address ⇒ Object
Optional custom email address from which to send the OTP email
32 33 34 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 32 def send_from_email_address @send_from_email_address end |
#send_from_email_sender_name ⇒ Object
Optional custom sender name for use with sendFromEmailAddress; if left empty, will default to ‘Notifications’
38 39 40 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 38 def send_from_email_sender_name @send_from_email_sender_name end |
#sms_customization ⇒ Object
Returns the value of attribute sms_customization.
26 27 28 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 26 def sms_customization @sms_customization end |
#user_identifier ⇒ Object
Optional client-generated user identifier to enable per-user rate limiting for SMS auth. We recommend using a hash of the client-side IP address.
29 30 31 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 29 def user_identifier @user_identifier end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 47 def self.attribute_map { :'otp_type' => :'otpType', :'contact' => :'contact', :'otp_length' => :'otpLength', :'email_customization' => :'emailCustomization', :'sms_customization' => :'smsCustomization', :'user_identifier' => :'userIdentifier', :'send_from_email_address' => :'sendFromEmailAddress', :'alphanumeric' => :'alphanumeric', :'send_from_email_sender_name' => :'sendFromEmailSenderName', :'expiration_seconds' => :'expirationSeconds', :'reply_to_email_address' => :'replyToEmailAddress' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
209 210 211 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 209 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 81 def self.openapi_nullable Set.new([ :'otp_length', :'user_identifier', :'send_from_email_address', :'alphanumeric', :'send_from_email_sender_name', :'expiration_seconds', :'reply_to_email_address' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 64 def self.openapi_types { :'otp_type' => :'Object', :'contact' => :'Object', :'otp_length' => :'Object', :'email_customization' => :'Object', :'sms_customization' => :'Object', :'user_identifier' => :'Object', :'send_from_email_address' => :'Object', :'alphanumeric' => :'Object', :'send_from_email_sender_name' => :'Object', :'expiration_seconds' => :'Object', :'reply_to_email_address' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 178 def ==(o) return true if self.equal?(o) self.class == o.class && otp_type == o.otp_type && contact == o.contact && otp_length == o.otp_length && email_customization == o.email_customization && sms_customization == o.sms_customization && user_identifier == o.user_identifier && send_from_email_address == o.send_from_email_address && alphanumeric == o.alphanumeric && send_from_email_sender_name == o.send_from_email_sender_name && expiration_seconds == o.expiration_seconds && reply_to_email_address == o.reply_to_email_address end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 239 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TurnkeyClient.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 308 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 216 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) end end self end |
#eql?(o) ⇒ Boolean
196 197 198 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 196 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
202 203 204 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 202 def hash [otp_type, contact, otp_length, email_customization, sms_customization, user_identifier, send_from_email_address, alphanumeric, send_from_email_sender_name, expiration_seconds, reply_to_email_address].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 155 def list_invalid_properties invalid_properties = Array.new if @otp_type.nil? invalid_properties.push('invalid value for "otp_type", otp_type cannot be nil.') end if @contact.nil? invalid_properties.push('invalid value for "contact", contact cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
284 285 286 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 284 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 290 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
278 279 280 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 278 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
170 171 172 173 174 |
# File 'lib/turnkey_client/models/init_otp_intent.rb', line 170 def valid? return false if @otp_type.nil? return false if @contact.nil? true end |