Class: TurnkeyClient::InvitationsApi
- Inherits:
-
Object
- Object
- TurnkeyClient::InvitationsApi
- Defined in:
- lib/turnkey_client/api/invitations_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_invitations(body, opts = {}) ⇒ ActivityResponse
Create Invitations Create Invitations to join an existing Organization.
-
#create_invitations_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Create Invitations Create Invitations to join an existing Organization.
-
#delete_invitation(body, opts = {}) ⇒ ActivityResponse
Delete Invitation Delete an existing Invitation.
-
#delete_invitation_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Delete Invitation Delete an existing Invitation.
-
#initialize(api_client = ApiClient.default) ⇒ InvitationsApi
constructor
A new instance of InvitationsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ InvitationsApi
Returns a new instance of InvitationsApi.
16 17 18 |
# File 'lib/turnkey_client/api/invitations_api.rb', line 16 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
14 15 16 |
# File 'lib/turnkey_client/api/invitations_api.rb', line 14 def api_client @api_client end |
Instance Method Details
#create_invitations(body, opts = {}) ⇒ ActivityResponse
Create Invitations Create Invitations to join an existing Organization
24 25 26 27 |
# File 'lib/turnkey_client/api/invitations_api.rb', line 24 def create_invitations(body, opts = {}) data, _status_code, _headers = create_invitations_with_http_info(body, opts) data end |
#create_invitations_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Create Invitations Create Invitations to join an existing Organization
34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/turnkey_client/api/invitations_api.rb', line 34 def create_invitations_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InvitationsApi.create_invitations ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling InvitationsApi.create_invitations" end # resource path local_var_path = '/public/v1/submit/create_invitations' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: InvitationsApi#create_invitations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_invitation(body, opts = {}) ⇒ ActivityResponse
Delete Invitation Delete an existing Invitation
82 83 84 85 |
# File 'lib/turnkey_client/api/invitations_api.rb', line 82 def delete_invitation(body, opts = {}) data, _status_code, _headers = delete_invitation_with_http_info(body, opts) data end |
#delete_invitation_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Delete Invitation Delete an existing Invitation
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/turnkey_client/api/invitations_api.rb', line 92 def delete_invitation_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InvitationsApi.delete_invitation ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling InvitationsApi.delete_invitation" end # resource path local_var_path = '/public/v1/submit/delete_invitation' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: InvitationsApi#delete_invitation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |