Class: TurnkeyClient::OrganizationsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/turnkey_client/api/organizations_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ OrganizationsApi

Returns a new instance of OrganizationsApi.



16
17
18
# File 'lib/turnkey_client/api/organizations_api.rb', line 16

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



14
15
16
# File 'lib/turnkey_client/api/organizations_api.rb', line 14

def api_client
  @api_client
end

Instance Method Details

#create_sub_organization(body, opts = {}) ⇒ V1ActivityResponse

Create Sub-Organization Create a new Sub-Organization

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



24
25
26
27
# File 'lib/turnkey_client/api/organizations_api.rb', line 24

def create_sub_organization(body, opts = {})
  data, _status_code, _headers = create_sub_organization_with_http_info(body, opts)
  data
end

#create_sub_organization_with_http_info(body, opts = {}) ⇒ Array<(V1ActivityResponse, Integer, Hash)>

Create Sub-Organization Create a new Sub-Organization

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(V1ActivityResponse, Integer, Hash)>)

    V1ActivityResponse data, response status code and response headers



34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/turnkey_client/api/organizations_api.rb', line 34

def create_sub_organization_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationsApi.create_sub_organization ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationsApi.create_sub_organization"
  end
  # resource path
  local_var_path = '/public/v1/submit/create_sub_organization'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(body) 

  return_type = opts[:return_type] || 'V1ActivityResponse' 

  auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type)

  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationsApi#create_sub_organization\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_organization(body, opts = {}) ⇒ V1GetOrganizationResponse

Get Organization Get details about an Organization

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



82
83
84
85
# File 'lib/turnkey_client/api/organizations_api.rb', line 82

def get_organization(body, opts = {})
  data, _status_code, _headers = get_organization_with_http_info(body, opts)
  data
end

#get_organization_with_http_info(body, opts = {}) ⇒ Array<(V1GetOrganizationResponse, Integer, Hash)>

Get Organization Get details about an Organization

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(V1GetOrganizationResponse, Integer, Hash)>)

    V1GetOrganizationResponse data, response status code and response headers



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/turnkey_client/api/organizations_api.rb', line 92

def get_organization_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationsApi.get_organization ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationsApi.get_organization"
  end
  # resource path
  local_var_path = '/public/v1/query/get_organization'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(body) 

  return_type = opts[:return_type] || 'V1GetOrganizationResponse' 

  auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type)

  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationsApi#get_organization\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_root_quorum(body, opts = {}) ⇒ V1ActivityResponse

Update Root Quorum Set the threshold and members of the root quorum. This must be approved by the current root quorum.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



140
141
142
143
# File 'lib/turnkey_client/api/organizations_api.rb', line 140

def update_root_quorum(body, opts = {})
  data, _status_code, _headers = update_root_quorum_with_http_info(body, opts)
  data
end

#update_root_quorum_with_http_info(body, opts = {}) ⇒ Array<(V1ActivityResponse, Integer, Hash)>

Update Root Quorum Set the threshold and members of the root quorum. This must be approved by the current root quorum.

Parameters:

  • body
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(V1ActivityResponse, Integer, Hash)>)

    V1ActivityResponse data, response status code and response headers



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/turnkey_client/api/organizations_api.rb', line 150

def update_root_quorum_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationsApi.update_root_quorum ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationsApi.update_root_quorum"
  end
  # resource path
  local_var_path = '/public/v1/submit/update_root_quorum'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(body) 

  return_type = opts[:return_type] || 'V1ActivityResponse' 

  auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type)

  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationsApi#update_root_quorum\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end