Class: TurnkeyClient::UsersApi
- Inherits:
-
Object
- Object
- TurnkeyClient::UsersApi
- Defined in:
- lib/turnkey_client/api/users_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_users(body, opts = {}) ⇒ ActivityResponse
Create Users Create Users in an existing Organization.
-
#create_users_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Create Users Create Users in an existing Organization.
-
#delete_users(body, opts = {}) ⇒ ActivityResponse
Delete Users Delete Users within an Organization.
-
#delete_users_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Delete Users Delete Users within an Organization.
-
#get_user(body, opts = {}) ⇒ GetUserResponse
Get User Get details about a User.
-
#get_user_with_http_info(body, opts = {}) ⇒ Array<(GetUserResponse, Integer, Hash)>
Get User Get details about a User.
-
#get_users(body, opts = {}) ⇒ GetUsersResponse
List Users List all Users within an Organization.
-
#get_users_with_http_info(body, opts = {}) ⇒ Array<(GetUsersResponse, Integer, Hash)>
List Users List all Users within an Organization.
-
#initialize(api_client = ApiClient.default) ⇒ UsersApi
constructor
A new instance of UsersApi.
-
#update_user(body, opts = {}) ⇒ ActivityResponse
Update User Update a User in an existing Organization.
-
#update_user_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Update User Update a User in an existing Organization.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ UsersApi
Returns a new instance of UsersApi.
16 17 18 |
# File 'lib/turnkey_client/api/users_api.rb', line 16 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
14 15 16 |
# File 'lib/turnkey_client/api/users_api.rb', line 14 def api_client @api_client end |
Instance Method Details
#create_users(body, opts = {}) ⇒ ActivityResponse
Create Users Create Users in an existing Organization
24 25 26 27 |
# File 'lib/turnkey_client/api/users_api.rb', line 24 def create_users(body, opts = {}) data, _status_code, _headers = create_users_with_http_info(body, opts) data end |
#create_users_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Create Users Create Users in an existing Organization
34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/turnkey_client/api/users_api.rb', line 34 def create_users_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.create_users ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling UsersApi.create_users" end # resource path local_var_path = '/public/v1/submit/create_users' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#create_users\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_users(body, opts = {}) ⇒ ActivityResponse
Delete Users Delete Users within an Organization
82 83 84 85 |
# File 'lib/turnkey_client/api/users_api.rb', line 82 def delete_users(body, opts = {}) data, _status_code, _headers = delete_users_with_http_info(body, opts) data end |
#delete_users_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Delete Users Delete Users within an Organization
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/turnkey_client/api/users_api.rb', line 92 def delete_users_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.delete_users ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling UsersApi.delete_users" end # resource path local_var_path = '/public/v1/submit/delete_users' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#delete_users\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_user(body, opts = {}) ⇒ GetUserResponse
Get User Get details about a User
140 141 142 143 |
# File 'lib/turnkey_client/api/users_api.rb', line 140 def get_user(body, opts = {}) data, _status_code, _headers = get_user_with_http_info(body, opts) data end |
#get_user_with_http_info(body, opts = {}) ⇒ Array<(GetUserResponse, Integer, Hash)>
Get User Get details about a User
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/turnkey_client/api/users_api.rb', line 150 def get_user_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.get_user ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling UsersApi.get_user" end # resource path local_var_path = '/public/v1/query/get_user' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'GetUserResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#get_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_users(body, opts = {}) ⇒ GetUsersResponse
List Users List all Users within an Organization
198 199 200 201 |
# File 'lib/turnkey_client/api/users_api.rb', line 198 def get_users(body, opts = {}) data, _status_code, _headers = get_users_with_http_info(body, opts) data end |
#get_users_with_http_info(body, opts = {}) ⇒ Array<(GetUsersResponse, Integer, Hash)>
List Users List all Users within an Organization
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/turnkey_client/api/users_api.rb', line 208 def get_users_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.get_users ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling UsersApi.get_users" end # resource path local_var_path = '/public/v1/query/list_users' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'GetUsersResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#get_users\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_user(body, opts = {}) ⇒ ActivityResponse
Update User Update a User in an existing Organization
256 257 258 259 |
# File 'lib/turnkey_client/api/users_api.rb', line 256 def update_user(body, opts = {}) data, _status_code, _headers = update_user_with_http_info(body, opts) data end |
#update_user_with_http_info(body, opts = {}) ⇒ Array<(ActivityResponse, Integer, Hash)>
Update User Update a User in an existing Organization
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/turnkey_client/api/users_api.rb', line 266 def update_user_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.update_user ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling UsersApi.update_user" end # resource path local_var_path = '/public/v1/submit/update_user' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(body) return_type = opts[:return_type] || 'ActivityResponse' auth_names = opts[:auth_names] || ['ApiKeyAuth', 'AuthenticatorAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#update_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |